C     ***************                                                   
C     *             *                                                   
C     * R M E T 2 1 *                                                   
C     *             *                                                   
C     ***************                                                 
C                                                                       
C     Program for calculations of neutron spectra and cross sections 
C     in the resonance energy region, with energy details, for 
C     homogeneous mixtures and cylindrical pin cells
C                                                                       
C     Author: Francisco Leszczynski                                 
C             Centro Atomico Bariloche                                   
C             8400 S.C.de Bariloche, RN
C             ARGENTINA
C                                                                       
C     First version: February 1985
C     This version:  March    1999
C--------------------------------------------------------------------------------
c                                                                        rmet21.1    
c     program rmet21                                                     rmet21.2    
c                                                                        rmet21.3    
c     ****************************************************************** rmet21.4    
c     *                                                                * rmet21.5    
c     * Calculate neutron flux on the energy region of neutron         * rmet21.6    
c     * resonances of heavy isotopes for homogeneous systems and       * rmet21.7    
c     * cylindrical pin cells, on a very fine energy mesh of constant  * rmet21.8
c     * lethargy.                                                      * rmet21.9
c     * Program GEXSCO is used for preparation of input resonant cross * rmet21.10
c     * section files.                                                 * rmet21.11
c     * The calculated flux is used for generating several parameters  * rmet21.12
c     * integrated over broad energy groups:                           * rmet21.13
c     *                                                                * rmet21.14
c     * >For homogeneous mixtures of one resonant isotope and hydrogen * rmet21.15
c     *  on different dilutions, resonance integrals of WIMSD type are * rmet21.16
c     *  produced.                                                     * rmet21.17   
c     *                                                                * rmet21.18
c     * >For homogeneous mixtures of one resonant isotope, hydorgen    * rmet21.19
c     *  and one X isotope, absorption cross sections for broad groups * rmet21.20
c     *  are calculated, for input to program ALAMBDA,                 * rmet21.21   
c     *  for calculations of lambda factors used on WIMSD libraries.   * rmet21.22
c     *                                                                * rmet21.23
c     * >For cylindrical pin cells, absorption, fission and scattering * rmet21.24
c     *  cross sections are output, in function of broad groups,       * rmet21.25
c     *  spatial regions and integrated over spatial zones.            * rmet21.26
c     *                                                                * rmet21.27
c     * >For homogeneous and pin cell cases, fluxes over intermediate  * rmet21.28
c     *  energy points can be output.                                  * rmet21.29
c     *                                                                * rmet21.30   
c     *    --- input ---                                               * rmet21.31   
c     *                                                                * rmet21.32   
c     * file        contents                                           * rmet21.33   
c     * RMET21.DAT  main input file                                    * rmet21.34   
c     * XS1:        output of GEXSCO program for the resonant isotope  * rmet21.35  
c     *             (and XS2,XS3,...if more than one resonant isotope  * rmet21.36  
c     *              is present in the problem)                        * rmet21.37  
c     * RI.DAT:     reference resonance integrals (optional)           * rmet21.38  
c     *             format: equal to output RI.OUT file                * rmet21.39
c     *                                                                * rmet21.40
c     *                                                                * rmet21.41   
c     *    --- output ---                                              * rmet21.42   
c     *                                                                * rmet21.43   
c     * file        contents                                           * rmet21.44   
c     * RMET21.OUT  main output file                                   * rmet21.45   
c     * RI.OUT      # of broad group, XSb, absRI/du, nu*fisRI/du       * rmet21.46   
c     *             (XSb: background cross section,                    * rmet21.47
c     *              absRI/du,nu*fisRI/du: WIMSD type resonance        * rmet21.48
c     *                                    integrals                   * rmet21.49
c     * FIS7.OUT    intermediate energy,                               * rmet21.50
c     *             total cross section of spatial region 1,           * rmet21.51   
c     *             mean integrated flux on each spatial region        * rmet21.52
c     * ABSXS       broad group absorption cross sections              * rmet21.53
c     *             (input for ALAMBDA program)                        * rmet21.54   
c     *                                                                * rmet21.55   
c     *---input specifications (free format) in file RMET21.DAT--------* rmet21.56   
c     *                                                                * rmet21.57   
c     * card 1                                                         * rmet21.58   
c     *    nprob    number of problems                                 * rmet21.59   
c     * card 2                                                         * rmet21.60   
c     *    tit      descriptive character string (80 char max)         * rmet21.61   
c     * card 3                                                         * rmet21.62   
c     *    iopg     geometry option                                    * rmet21.63   
c     *               0  homogeneous                                   * rmet21.64
c     *               1  pin cell                                      * rmet21.65
c     *                                                                * rmet21.66  
c     *    --- cards 4-7: homogeneous options (iopg=0 only) ---        * rmet21.67   
c     *                                                                * rmet21.68  
c     * card 4                                                         * rmet21.69   
c     *    iopo     type of output                                     * rmet21.70   
c     *               0  cross sections                                * rmet21.71
c     *               1  resonance integrals                           * rmet21.72
c     *               2  lambda factor                                 * rmet21.73
c     * card 5 (iopo=1,2 only)                                         * rmet21.74  
c     *    iopb     type of XSb input                                  * rmet21.75   
c     *               0  read atomic densities                         * rmet21.76
c     *               1  read XSb                                      * rmet21.77
c     * card 6 (iopo=2 only)                                           * rmet21.78  
c     *    iopd     variable density option                            * rmet21.79   
c     *               0  variable h  density                           * rmet21.80
c     *               1  variable x density                            * rmet21.81
c     * card 7 (iopo=1 only)                                           * rmet21.82  
c     *    iopc     comparison with reference table option             * rmet21.83   
c     *               0  no                                            * rmet21.84
c     *               1  yes                                           * rmet21.85
c     *    ----------------------------------------------------        * rmet21.86   
c     * card 8                                                         * rmet21.87  
c     *    ngg      number of broad energy groups                      * rmet21.88  
c     *    niso     total number of isotopes                           * rmet21.89  
c     *    isres    total number of resonant isotopes                  * rmet21.90  
c     *    ngi      number of intermediate energy groups               * rmet21.91
c     * card 9 (iopo=0,1 only)                                         * rmet21.92  
c     *    anufis   nu of fisil resonant isotope (=0:no fisil isotope) * rmet21.93   
c     *               0  no                                            * rmet21.94
c     *               1  yes                                           * rmet21.95
c     * card 10 (iopo=1,2 only)                                        * rmet21.96  
c     *    alambda  lambda factor of resonant isotope                  * rmet21.97   
c     * card 11 (iopg=1 only)                                          * rmet21.98  
c     *    nmat     number of materials                                * rmet21.99  
c     *    nreg     number of regions                                  * rmet21.100  
c     *    nz       number of zones                                    * rmet21.101  
c     *    ismax    maximum number of isotopes per material            * rmet21.102
c     *    nirmax   maximum number of resonant isotopes per material   * rmet21.103
c     *                                                                * rmet21.104
c     * card 12                                                        * rmet21.105  
c     *    isma(i)  number of broad energy groups                      * rmet21.106  
c     * card 13                                                        * rmet21.107  
c     *    id(i,j)  identifiers k of isotopes j (see cards 16-20)      * rmet21.108  
c     *             (j=1,isma(i))                                      * rmet21.109
c     * card 14                                                        * rmet21.110  
c     *    dn(i,j)  atomic densities of isotopes j (j=1,isma(i))       * rmet21.111
c     * card 15                                                        * rmet21.112  
c     *    temp(i)  temperature (k) of material i (for reference only) * rmet21.113  
c     *                                                                * rmet21.114
c     *  repeat cards 12-15 for i=1,nmat                               * rmet21.115
c     *                                                                * rmet21.116  
c     * card 16                                                        * rmet21.117  
c     *    simbo(k) symbol of isotope k (4 char max)                   * rmet21.118  
c     * card 17                                                        * rmet21.119  
c     *    c(k)     atomic mass in unit of neutron mass of isotope k   * rmet21.120  
c     * card 18                                                        * rmet21.121  
c     *    nres(k)  resonant isotope specification for k               * rmet21.122
c     *               0  no                                            * rmet21.123
c     *               1  yes                                           * rmet21.124
c     * card 19                                                        * rmet21.125  
c     *    xsp(k)   potential cross section (barns) of isotope k       * rmet21.126  
c     * card 20 (nres(k)=0 only)                                       * rmet21.127  
c     *    xsa(k)   2200 m/sec-absorption cross section (barns) for k  * rmet21.128  
c     *    xsf(k)   2200 m/sec-fission cross section (barns) for k     * rmet21.129  
c     *                                                                * rmet21.130
c     *  repeat cards 16-20 for k=1,niso                               * rmet21.131
c     *                                                                * rmet21.132  
c     *    --- cards 21-23: pin cell data (iopg=1 only) ---            * rmet21.133  
c     *                                                                * rmet21.134  
c     * card 21                                                        * rmet21.135  
c     *    matr(l)  identifier i (see cards 12-15) of the material of  * rmet21.136
c     *             each region l from inner to outer regions          * rmet21.137
c     *             (l=1,nreg)                                         * rmet21.138
c     * card 22                                                        * rmet21.139  
c     *    r(l)     radius (cm) of each region l (l=1,nreg)            * rmet21.140  
c     *             from inner to outer regions                        * rmet21.141
c     * card 23                                                        * rmet21.142  
c     *    nrz(m)   number of regions on each zone m (m=1,nz)          * rmet21.143  
c     *             from inner to outer zones                          * rmet21.144
c     *    ----------------------------------------------------        * rmet21.145  
c     * card 24                                                        * rmet21.146  
c     *    ebg(ig)  energy (eV) of the lower boundaries of each        * rmet21.147  
c     *             output broad energy group (ig=1,ngg)               * rmet21.148
c     * card 25                                                        * rmet21.149  
c     *    iopf     option of intermediate flux record                 * rmet21.150  
c     *               0  no record                                     * rmet21.151
c     *               1  record intermediate fluxes on FIS7.OUT        * rmet21.152
c     * card 26                                                        * rmet21.153  
c     *    ncases   number of cases to be run with data of above       * rmet21.154  
c     *             cards 1-27, changing atomic densities only         * rmet21.155
c     *                                                                * rmet21.156  
c     *    --- cards 27a-28a (ncases.gt.1 and iopo=0,1 only) ---       * rmet21.157  
c     *                                                                * rmet21.158  
c     * card 27a                                                       * rmet21.159  
c     *    dn(i,j)  atomic densities of isotopes j (j=1,isma(i))       * rmet21.160
c     * card 28a                                                       * rmet21.161  
c     *    temp(i)  temperature (k) of material i (for reference only) * rmet21.162  
c     *  repeat cards 27a,28a for i=1,nmat                             * rmet21.163
c     *    ----------------------------------------------------        * rmet21.164  
c     * card 27b (ncases.gt.1 and iopo=2 only)                         * rmet21.165  
c     *    deltad   increment of the atomic density or XSb of the      * rmet21.166
c     *             isotope with variable density                      * rmet21.167
c     *                                                                * rmet21.168
c     *  repeat cards 27a,28a or 27b for n=2,ncases                    * rmet21.169
c     *                                                                * rmet21.170  
c     *  repeat cards 2-28 for ie=2,nprob                              * rmet21.171
c     *                                                                * rmet21.172
c     *  WARNING !!! :                                                 * rmet21.173
c     *  no-exhaustive consistency checks are automatically made on    * rmet21.174  
c     *  the input file. it is responsability of the user to check all * rmet21.175  
c     *  the entries on the input file, for each case.                 * rmet21.176
c     *                                                                * rmet21.177  
c     ****************************************************************** rmet21.178
c                                                                        rmet21.179
C----------------------------------------------------------------------------------      
      DIMENSION A(5000000)                                               
C                                                                       
      COMMON/A/ ID1, ID2 ,ID3 ,ID4 ,ID5 ,ID10,                          
     1          IS6 ,IS7 ,IS8 ,IS9                                      
C                                                                       
      COMMON/B/ NGG   ,NISO  ,ISRES ,NRSUM ,NGI   ,NTABXA,              
     1          NMAT  ,NREG  ,NZ    ,ISMAX ,NIRMAX,NX    ,              
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,              
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,              
     4          NGFI2 ,INXS  ,IT10  ,IT62  ,IGIAN ,IM    ,              
     5          IG                                                      
C                                                                       
      COMMON/C/ EMAX  ,DUGF  ,ALBEDO,AJEXT ,ANUFIS,URLAM ,              
     1          DUGI  ,SA    ,SB    ,SD    ,RE2SM ,VTOT  ,              
     2          PG    ,U     ,U3    ,Q0C   ,E22   ,EM    ,              
     3          SA1MIN,PG1   ,XSB   ,PERCON,SCOP  ,DXST(3),EMAR         
C                                                                       
      COMMON/D/ IOPI(16)                                                
C                                                                       
      COMMON/E/ L0    ,LAS 
C                                                                       
      COMMON/F/ TIT                                                 
C                                                                       
      COMMON/G/I0I(10),IPCAL(3)                                         
C              
      CHARACTER*80 TIT                                                         
      REAL*4 DTIME,CTIEM,FTIEM,TARRAY(2)
C
C                                                                       
  1   FORMAT('NUMBER OF CASES :',I5/)                                                      
C
  2   FORMAT('CASE :',I5/)  
C                                                                     
  3   FORMAT('TITLE:'/,A80)                                                    
C                                                                       
  4   FORMAT('GEOMETRY: HOMOGENEOUS MIXTURE')                                                      
C                                                                       
  5   FORMAT('GEOMETRY: PIN CELL')                                                   
C 
  6   FORMAT('REQUEST: XS CALCULATION')                                                   
C                                                                       
  7   FORMAT('REQUEST: XS AND RI CALCULATION')                                                       
C                                                                       
  8   FORMAT('REQUEST: LAMBDA CALCULATION')                                                    
C                                                                       
  9   FORMAT('RMET21 OUTPUT'///'INPUT DATA'//)                      
C
 10   FORMAT('OPTION1: READ Nx-XSb CALCULATED')
C
 11   FORMAT('OPTION1: READ XSb')                                                    
C
 12   FORMAT('OPTION2: Nh VARIABLE-Nx FIXED')
C
 13   FORMAT('OPTION2: Nx VARIABLE-Nh FIXED')
C
 14   FORMAT('OPTION3: NO COMPARISON OF CALCULATED RI WITH REFERENCE')
C
 15   FORMAT('OPTION3: COMPARISON OF CALCULATED RI WITH REFERENCE')
C
 16   FORMAT('NUMBER OF BROAD GROUPS=',I5)
C
 17   FORMAT('TOTAL NUMBER OF ISOTOPES=',I5)
C
 18   FORMAT('NUMBER OF RESONANT ISOTOPES=',I5)
C
 19   FORMAT('NUMBER OF INTERMEDIATE GROUPS=',I10)
C
 20   FORMAT('MEAN nu OF RESONANT ISOTOPE=',F10.7)
C
 21   FORMAT('NUMBER OF MATERIALS=',I5)
C
 22   FORMAT('NUMBER OF REGIONS=',I5)
C
 23   FORMAT('NUMBER OF ZONES=',I5)
C
 24   FORMAT('MAX.NUMBER OF ISOTOPES IN A MATERIAL=',I5)
C
 25   FORMAT('MAX.NUMBER OF RESONANT ISOTOPES IN A MATERIAL=',I5)
C
 26   FORMAT('lambda OF RESONANT ISOTOPE=',F10.7)
C                                                                       
 99   FORMAT('ERROR IN INPUT DATA .BYE')
C                                                                       
C   CALL TO FUNCTION DTIME FOR CPU TIME (SYSTEM DEPPENDENT CALL)
C
      CTIEM=DTIME(TARRAY)
C
      ID5=5                                                             
      IS6=4                                                             
C                                                                       
      OPEN(UNIT=ID5,FILE='RMET21.DAT',FORM='FORMATTED',STATUS='OLD')    
      OPEN(UNIT=IS6,FILE='RMET21.OUT',FORM='FORMATTED',STATUS='NEW')          
C                                                                       
C   CALL TO SUBROUTINE TIMEDATE. 
C   THE USER MAY SUPPLY THE APPROPRIATE SUBROUTINE WITH DATE AND TIME
C   FOR EACH COMPUTER SYSTEM. 
C   At the end of this listing it is included an elemental subroutine 
C   TIMEDATE that gives the clock time and the date for PC's. The same 
C   subroutine is called at the end of calculations.
      CALL TIMEDATE
      IM=1                                                              
      NX=3                                                              
      NX1=2                                                             
      L0=5000000                                                         
      E22=2.52973E-02                                                   
      SA1MIN=1.0000E-15                                                 
C                                                                       
C                                                                       
      WRITE(IS6,9)                                                      
      READ(ID5,*)NENTRA                                                 
      IF(NENTRA.GT.0)THEN
       WRITE(IS6,1)NENTRA                                                
      ELSE
       WRITE(IS6,99)
       STOP
      ENDIF
C                                                                       
      DO IENTRA=1,NENTRA                                             
C
      WRITE(IS6,2)IENTRA                                                                                                                                              
C
      READ(ID5,'(A80)')TIT                                        
      WRITE(IS6,3)TIT
C                                                                       
      I0I(1)=1
      I0I(2)=0
      I0I(3)=0
      I0I(4)=0
      I0I(5)=0
      I0I(6)=0
      I0I(7)=0
      I0I(8)=0
      I0I(9)=0
      I0I(10)=0
C
      READ(ID5,*)IOPI(1)
      IF(IOPI(1).EQ.0)THEN 
       WRITE(IS6,4)
      ELSEIF(IOPI(1).EQ.1)THEN
       WRITE(IS6,5)
      ELSE
       WRITE(IS6,99)
       STOP
      ENDIF
C                                                                       
      IOPI(2)=1                                                         
      IOPI(3)=0                                                         
      IOPI(4)=2
      IOPI(5)=0
      IOPI(6)=0
      IOPI(7)=1                                                         
      IOPI(8)=0                                                         
      IOPI(9)=0
      IOPI(10)=0
      IOPI(11)=0                                                         
      IOPI(12)=0                                                        
      IOPI(13)=0
      IOPI(14)=0                                                        
      IOPI(15)=0                                                        
      IOPI(16)=0         
C
      IF(IOPI(1).EQ.0)THEN 
       READ(ID5,*)IOPI(3)
       IF(IOPI(3).EQ.0)THEN
        WRITE(IS6,6)
       ELSEIF(IOPI(3).EQ.1)THEN
        WRITE(IS6,7)
       ELSEIF(IOPI(3).EQ.2)THEN
        WRITE(IS6,8)
       ELSE
        WRITE(IS6,99)
        STOP
       ENDIF
       IF(IOPI(3).GT.0)THEN
        READ(ID5,*)IOPI(5)
        IF(IOPI(5).EQ.0)THEN
         WRITE(IS6,10)
        ELSEIF(IOPI(5).EQ.1)THEN
         WRITE(IS6,11)
        ELSE
         WRITE(IS6,99)
         STOP
        ENDIF
        IF(IOPI(3).EQ.1)THEN
         READ(ID5,*)IOPI(11)
         IF(IOPI(11).EQ.0)THEN
          WRITE(IS6,14)
         ELSEIF(IOPI(11).EQ.1)THEN
          WRITE(IS6,15)
         ELSE
          WRITE(IS6,99)
          STOP
         ENDIF
        ELSEIF(IOPI(3).EQ.2)THEN
         READ(ID5,*)IOPI(6)
         IF(IOPI(6).EQ.0)THEN
          WRITE(IS6,12)
         ELSEIF(IOPI(6).EQ.1)THEN
          WRITE(IS6,13)
         ELSE
          WRITE(IS6,99)
          STOP
         ENDIF
        ENDIF
       ENDIF
      ENDIF
C
C     Input/output units
C                                                                       
      ID1=1                                                             
      ID2=2                                                             
      ID3=3                                                             
      ID4=40                                                             
      IS7=7                                                             
      IS8=8                                                             
      IS9=9                                                             
      ID10=10                                                           
C                                                                       
C     General data 1 
C
C     NGG  : # de broad energy groups
C     NISO : # of isotopes 
C     ISRES: # of reso isotopes (<=NISO)
C     NGI  : # of intermediate groups
C
      READ(ID5,*) NGG,NISO,ISRES,NGI
      WRITE(IS6,16)NGG
      WRITE(IS6,17)NISO
      WRITE(IS6,18)ISRES
      WRITE(IS6,19)NGI
C                                                                       
C     General data 2 
C
C     ANUFIS : IOPI(3)<=1, nu of reference reso fissile isotope 
C     URLAM  : HOMO.,IOPI(3)>=1, lambda of reference reso isotope 
C
      IF(IOPI(3).LT.2)THEN
       READ(ID5,*) ANUFIS
       WRITE(IS6,20)ANUFIS
      ENDIF
C
      IF(IOPI(3).GT.0)THEN
       READ(ID5,*) URLAM
       WRITE(IS6,26)URLAM
      ENDIF
C
      IF(IOPI(1).EQ.0)THEN                                                                                                                
       
       NMAT=1                                                            
       NREG=1                                                            
       NZ=1                                                              
       ISMAX=NISO                                                        
       NIRMAX=ISRES                                                      

      ELSE                                                          
C                                                                       
C     General heterogeneous data 1 
C
C      NMAT  : # of materiales 
C      NREG  : # of spatial regions
C      NZ    : # of spatial zones (<=NREG)
C      ISMAX : Max.# of isotopes on one material 
C      NIRMAX: Max.# of reso isotopes on one material
C
       READ(ID5,*)NMAT,NREG,NZ,ISMAX,NIRMAX
       WRITE(IS6,21)NMAT
       WRITE(IS6,22)NREG
       WRITE(IS6,23)NZ
       WRITE(IS6,24)ISMAX
       WRITE(IS6,25)NIRMAX
C
       IG=5                                                        
       ALBEDO=1.0                                                        
       AJEXT=0.0                                                         
C                                                                       
      ENDIF
C                                                                       
C     Dimens.1                                                
C                                                                       
      DO I=1,L0                                                         
       A(I)=0.0                                                         
      END DO                                                            
C                                                                       
      LISMA=1                                                           
      LID=LISMA+NMAT                                                    
      LNRES=LID+NMAT*ISMAX                                              
      LMATR=LNRES+NISO                                                  
      LNGF=LMATR+NREG                                                   
      LL=LNGF+NGG                                                       
      LIRUB=LL+NISO                                                     
      LNRZ=LIRUB+NISO                                                   
      LTEMP=LNRZ+NZ                                                     
      LXS22=LTEMP+NMAT                                                  
      LC=LXS22+NISO*NX                                                  
      LDUGG=LC+NISO                                                     
      LSA1=LDUGG+NGG                                                    
      LUMAX=LSA1+NISO                                                                                                        
      LV=LUMAX+NISO                                                       
      LSIMBO=LV+NREG                                                  
      LR1=LSIMBO+NISO                                                   
      LDN=LR1+NREG                                                      
      LXSI=LDN+NMAT*ISMAX                                               
      LR2=LXSI+NISO                                                     
      LEGF=LR2+NREG                                                      
      LIFISI=LEGF+NGG
      LA1=LIFISI+ISRES
      LAS=LA1-1                                                         
C                                                                       
C     Main calculation
C                                                                       
      CALL PRINCI (NMAT  ,NISO  , ISRES,                                      
     1             A(LISMA) ,A(LID)   ,A(LNRES) ,A(LMATR) ,             
     2             A(LNGF)  ,A(LL)    ,A(LIRUB) ,A(LNRZ)  ,             
     3             A(LTEMP) ,A(LXS22) ,A(LC)    ,A(LDUGG) ,             
     4             A(LSA1)  ,A(LUMAX) ,A(LV)    ,A(LSIMBO),
     5             A(LR1)   ,A(LDN)   ,A(LXSI)  ,A(LA1)   ,
     6             A(LR2)   ,A(LEGF),A(LIFISI))   
C                                                                       
      ENDDO
C                                                                       
C   CALL TO SUBROUTINE TIMEDATE AND FUNCTION DTIME FOR CPU TIME. 
C   THE USER MAY SUPPLY THE APPROPRIATE SUBROUTINE WITH DATE AND TIME
C   FOR EACH COMPUTER SYSTEM
      CALL TIMEDATE
      FTIEM=DTIME(TARRAY)
      write(4,'("Total cpu time(min)=",f10.3)')FTIEM/60.0
C
      CLOSE(4)                                                        
      CLOSE(5)
      CLOSE(7)
      CLOSE(40)
      CLOSE(60)
      CLOSE(70)
C
C
C
      STOP                                                              
      END                                                               
C*****************************************************************************
C
C     ***************                                                     
C     *             *                                                     
C     * P R I N C I *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C                   Read array data,                            
C                   performs dimens.2,                        
C                   calculates initial parameters                            
C                   call calculation and output subrutines                   
C                                                                         
      SUBROUTINE PRINCI (NMAT ,NISO , ISRES,                                    
     1                   ISMA ,ID   ,NRES ,MATR ,             
     2                   NGF  ,L    ,IRUB ,NRZ  ,             
     3                   TEMP ,XS22 ,C    ,DUGG ,             
     4                   SA1  ,UMAX ,V    ,SIMBO,
     5                   R1   ,DN   ,XSI  ,A1   ,
     6                   R2   ,EGF,IFISIO)   
C                                                                         
      DIMENSION ISMA(1)     ,ID(NMAT,1)  ,NRES(1)      ,MATR(1)     ,     
     1          NGF(1)      ,L(1)        ,IRUB(1)      ,NRZ(1)      ,     
     2          TEMP(1)     ,XS22(NISO,1),C(1)         ,DUGG(1)     ,     
     3          SA1(1)      ,UMAX(1)     ,V(1)         ,SIMBO(1)    ,
     4          R1(1)       ,DN(NMAT,1)  ,XSI(1)       ,A1(1)       ,
     5          R2(1)       ,EGF(1) ,IFISIO(1)    
C                                                                         
      CHARACTER*3 NOMXS(9)                                             
C                                                                       
      COMMON/A/ ID1, ID2 ,ID3 ,ID4 ,ID5 ,ID10,                            
     1          IS6 ,IS7 ,IS8 ,IS9                                        
C                                                                         
      COMMON/B/ NGG   ,NXX1  ,NZZ1 ,NRSUM ,NGI   ,NTABXA,                
     1          NXX2  ,NREG  ,NZ    ,ISMAX ,NIRMAX,NX    ,                
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,                
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,                
     4          NGFI2 ,INXS  ,IT10  ,IT62  ,IGIAN ,IM    ,                
     5          IG                                                        
C                                                                         
      COMMON/C/ EMAX  ,DUGF  ,ALBEDO,AJEXT ,ANUFIS,URLAM ,                
     1          DUGI  ,SA    ,SB    ,SD    ,RE2SM ,VTOT  ,                
     2          PG    ,U     ,U3    ,Q0C   ,E22   ,EM    ,                
     3          SA1MIN,PG1   ,XSB   ,PERCON,SCOP  ,DXST(3),EMAR           
C                                                                         
      COMMON/D/ IOPI(16)                                                  
C                                                                         
      COMMON/E/ L0, LAS                                         
C                                                                         
      COMMON/G/I0I(10),IPCAL(3)                                           
C                                                                         
      COMMON/AB/NIPP                                                    
C                                                                       
  1   FORMAT('MATERIAL DATA')                                                        
C                                                                         
  2   FORMAT(' MATERIAL=',I5)                                                    
C                                                                         
  3   FORMAT('  # OF ISOTOPES=',I5)                                                          
C                                                                       
  4   FORMAT('  ISOTOPES')                                                       
C                                                                         
  5   FORMAT(20I4)                                                   
C                                                                       
  6   FORMAT('  ATOMIC DENSITIES')                                                 
C                                                                       
  7   FORMAT(1P6E12.5)                                                     
C                                                                       
  8   FORMAT('  TEMPERATURE=',F10.3)                                                      
C
  9   FORMAT('ISOTOPIC DATA')
C
 10   FORMAT(' ISOTOPE=',I5)
C
 11   FORMAT('  SYMBOL= ',A4)
C                                                                        
 12   FORMAT('  (ATOMIC MASS)/(NEUTRON MASS)= ',F10.5)
C                                                                       
 13   FORMAT('  NO-RESONANT ISOTOPE')
C
 14   FORMAT('  RESONANT ISOTOPE')
C
 15   FORMAT('  POTENTIAL XS= ',1PE12.5)
C
 16   FORMAT('  2200-ABSORPITON XS= ',1PE12.5)
C
 17   FORMAT('  2200-FISSION XS= ',1PE12.5)
C
 18   FORMAT('REGIONS AND ZONES')
C
 19   FORMAT(' MATERIAL OF EACH REGION')
C
 20   FORMAT(' EXTERNAL RADIUS(CM) OF EACH REGION')
C
 21   FORMAT(' # DE REGIONS IN EACH ZONE')
C
 22   FORMAT('LOW BOUNDARY ENERGIES(eV) OF BROAD GROUPS')
C
 23   FORMAT('********************************************************')
C
 24   FORMAT('GENERAL DATA FROM RESONANT XS FILES:'/)
C
 25   FORMAT(' TOTAL ENERGY FINE GROUPS=',I10)
C
 26   FORMAT(' LETHARGY WIDTH OF FINE GROUPS=',1PE15.8)
C
 27   FORMAT(' MAX.ENERGY=',1PE15.8)
C
 28   FORMAT('PRELIMINARY CALCULATIONS'//
     1' NUMBER OF FINE GROUPS FOR EACH BROAD GROUP'/)
C
 29   FORMAT(8I10)
C
 30   FORMAT('NUMBER OF CASES WITH DIFFERENT ATOMIC DENSITIES=',I5/)
C
 31   FORMAT('VOLUMES OF REGIONS'/ 
     1'REGION    RADIUS(CM)  VOLUME[PI*(R(I)**2)]')
 32   FORMAT(I4,4X,1PE12.5,2X,1PE12.5)
C
 33   FORMAT('TOTAL=----------------',1PE12.5/)
C               
 34   FORMAT(' CASE    1 (WITH ATOMIC DENSITIES GIVEN ABOVE'/)
C
 35   FORMAT(' CASE',I5/)
C
 36   FORMAT('  DELTA Nh=',1PE12.5/)
C
 37   FORMAT('  DELTA Nx=',1PE12.5/)
C
 38   FORMAT('  CALCULATED NEW ATOMIC DENSITY=',1PE12.5/)
C
 39   FORMAT('  CALCULATED ATOMIC DENSITY=',1PE12.5/)
C
 40   FORMAT('  CALCULATED XSb=',1PE12.5/)
C
 41   FORMAT('  FINAL NUMBER OF FINE ENERGY GROUPS=',I10/)
C
 42   FORMAT('  LETHARGY WIDTH OF INTERMEDIATE GROUPS',1PE15.8/)
C
 43   FORMAT('  LETHARGY WIDTHS OF BROAD GROUPS'/)
C
 44   FORMAT(1P5E15.8)
C
 45   FORMAT('   NUMBER OF FINE GROUPS ON EACH INTERMEDIATE GROUP=',I10)
C
 48   FORMAT(' WRITE INTERMEDIATE FLUXES ON FIS7.OUT FILE')
C
      PI=3.1415927                                                      
      NOMXS(1)='XS1'                                                    
      NOMXS(2)='XS2'                                                    
      NOMXS(3)='XS3'                                                    
      NOMXS(4)='XS4'                                                    
      NOMXS(5)='XS5'                                                    
      NOMXS(6)='XS6'                                                    
      NOMXS(7)='XS7'                                                    
      NOMXS(8)='XS8'                                                    
      NOMXS(9)='XS9'                                                    
C                                                                         
C     Material data
C
C     ISMA(I),I=1,NMAT             : # of isotopes on material I
C     ID(I,J),I=1,NMAT;J=1,ISMA(I) : identifier of J-isotope
C     DN(I,J),I=1,NMAT;J=1,ISMA(I) : atomic density of J-isotope
C                                    on I-material (ats./(barn*cm)
C     TEMP(I),I=1,NMAT             : temperature of I-material (K)
C
      WRITE(IS6,1)
      DO I=1,NMAT                                                         
       WRITE(IS6,2)I
       READ(ID5,*) ISMA(I)                                                 
       WRITE(IS6,3)ISMA(I)                                                 
       ISMA1=ISMA(I)                                                       
       READ(ID5,*)(ID(I,J),J=1,ISMA1)                                      
       WRITE(IS6,4)
       WRITE(IS6,5)(ID(I,J),J=1,ISMA1)
       READ(ID5,*) (DN(I,J),J=1,ISMA1)
       WRITE(IS6,6)
       WRITE(IS6,7)(DN(I,J),J=1,ISMA1)
       READ(ID5,*)TEMP(I)                             
       WRITE(IS6,8)TEMP(I)
      END DO                                                              
C                                                                         
C     Isotopic data
C
C     XS22(I,J),I=1,NISO;J=1,3 : J=1: XSabs-2200m/s of I-isotope
C                                  2: XSfis-2200m/s of I-isotope
C                                  3: XSp (reso energy) of I-isotope
C     C(I),I=1,NISO            : A/An of I-isotope
C     SIMBO(I),I=1,NISO        : symbol of I-isotope (4 char max)
C     NRES(I),I=1,NISO         =0: I-isotope no reso
C                              =1: I-isotope is reso
C
      DO I=1,NISO
       DO J=1,2
        XS22(I,J)=0.0
       ENDDO
      ENDDO
C
      WRITE(IS6,9)
      DO I=1,NISO                                                         
       WRITE(IS6,10)I
       READ(ID5,'(A4)') SIMBO(I)                                                
       WRITE(IS6,11)SIMBO(I)                                                
       READ(ID5,*) C(I)                                 
       WRITE(IS6,12)C(I)                                 
       READ(ID5,*) NRES(I)
       IF(NRES(I).EQ.0)THEN 
        WRITE(IS6,13)
       ELSE
        WRITE(IS6,14)
       ENDIF
       READ(ID5,*) XS22(I,3)
       WRITE(IS6,15)XS22(I,3)
       IF(NRES(I).EQ.0)THEN
        READ(ID5,*) (XS22(I,J),J=1,2)
        WRITE(IS6,16)XS22(I,1)
        WRITE(IS6,17)XS22(I,2)
       ENDIF
      END DO                                                              
C                                                                       
      IF(IOPI(1).EQ.0)THEN                                            
C
       II1=1                                                               
       MATR(II1)=1                                                         
       R1(II1)=1.0                                                         
       NRZ(II1)=1                                                          
C
      ELSE
C                                                                         
C      Data for regions and zones (heterogeneous case)
C   
C      MATR(I),I=1,NREG : identifier of mat on I-region
C      R1(I),I=1,NREG   : exterior radius of I-region (cm)
C  
       WRITE(IS6,18)
       READ(ID5,*) (MATR(I),I=1,NREG)
       WRITE(IS6,19)
       WRITE(IS6,5)(MATR(I),I=1,NREG)
       READ(ID5,*)(R1(I),I=1,NREG)
       WRITE(IS6,20)
       WRITE(IS6,7)(R1(I),I=1,NREG)
C
       SCOP=2.0/(PI*R1(NREG))                                            
       PERCON=2.0*PI*R1(NREG)                                              
C
C      NRZ(I),I=1,NZ : # of regions in each zone I
C 
       READ(ID5,*) (NRZ(I),I=1,NZ)                                         
       WRITE(IS6,21)
       WRITE(IS6,5)(NRZ(I),I=1,NZ)                                         
C
      ENDIF
C
C     Low boundary energies of broad groups (from high to low-eV)
C
      WRITE(IS6,22)
      READ(ID5,*)(EGF(I),I=1,NGG)
      WRITE(IS6,7)(EGF(I),I=1,NGG)
C
C      I0I(9): intermediate flux record(0: no;1; yes)
C 
       READ(ID5,*) IOPI(12)                                         
       IF(IOPI(12).EQ.1)THEN
        WRITE(IS6,48)
       ENDIF  
C
C     NCASOS : # of calculs with new input of atomic densities
C                                                                     
      READ(ID5,*) NCASOS                                                  
      WRITE(IS6,30)NCASOS                                                  
C
      WRITE(IS6,23)
C 
C     Read NGFTOT,EMAX,DUGF from XS1
C
C      NGFTOT : # of fine groups in XSres files
C      EMAX   : max energy in XSres files (= max energy of calculs)
C      DUGF   : lethargy widths of each fine group (constant)
C
       OPEN(UNIT=11,FILE='XS1',FORM='UNFORMATTED',STATUS='OLD')
C
       ID11=11
C
       WRITE(IS6,24)
C
       READ(ID11)NGFTOT,IFISIO(1),IT10
       WRITE(IS6,25)NGFTOT
C  
       READ(ID11)DUGF
       WRITE(IS6,26)DUGF
C
       READ(ID11)EMAX
       WRITE(IS6,27)EMAX
       EMAR=EMAX
C
       CLOSE(11)
       WRITE(IS6,23)
C
C      Calcul of the number of fine groups x broad group
C
      E0001=EMAX           
      N0001=0
      DO I=1,NGG
       NGF(I)=ALOG(E0001/EGF(I))/DUGF
       E0001=EGF(I)
       N0001=N0001+NGF(I)
      ENDDO
      IDIFN=NGFTOT-N0001
      IF(IDIFN.GT.0)THEN
       IDIFNN=IDIFN
 420   DO INN=NGG,1,-1
        IF(IDIFNN.GT.0)THEN
         NGF(INN)=NGF(INN)+1
         IDIFNN=IDIFNN-1
        ENDIF
       ENDDO
       IF(IDIFNN.GT.0)GOTO 420
      ENDIF
      WRITE(IS6,28)
      WRITE(IS6,29)(NGF(I),I=1,NGG)                                        
C                                                                       
C     Calcul of energy parameters                                    
C                                                                         
      CALL PARENE(NGF,DUGG)                                               
C
      WRITE(IS6,41)NGFT
      WRITE(IS6,42)DUGI
      WRITE(IS6,43)
      WRITE(IS6,44)(DUGG(IDUGG),IDUGG=1,NGG)
      WRITE(IS6,45)NGFI
C                                                                         
C     Calcul of isotope parameters                                    
C
      CALL PARISO(NISO,C,L,XSI,XS22,UMAX,SA1)                             
C                                                                         
C     Calcul of volumes                                                
C                                                                         
      VTOT=1.0                                                            
      IF(IOPI(1).EQ.1)THEN                                           
       WRITE(IS6,31)
       VA=0.0                                                              
       DO I=1,NREG                                                     
        R2(I)=R1(I)*R1(I)                                                   
        V(I)=PI*(R2(I)-VA)                                                  
        WRITE(IS6,32)I,R1(I),V(I)
        VA=R2(I)                                                         
       ENDDO
       VTOT=PI*R2(NREG)                                                    
       WRITE(IS6,33)VTOT
      ENDIF
C                                                                         
C     Dimens.2                                                  
C                                                                         
      LXSIM=1                                                             
      LXSPIM=LXSIM+NMAT*ISMAX*NX                                          
      LQ=LXSPIM+NMAT*ISMAX                                                
      LXSFI=LQ+NREG                                                       
      LXS1=LXSFI+NREG*NGI*ISMAX                                           
      LXSGG=LXS1+NX                                                       
      LXST=LXSGG+NREG                                                     
      LXSTA=LXST+NREG                                                     
      LXSTA2=LXSTA+NREG                                                   
      LXSTA3=LXSTA2+NREG                                                  
      LXS2=LXSTA3+NREG                                                    
      LFI=LXS2+NX                                                         
      LXSR=LFI+NREG                                                       
      LFR=LXSR+NREG+1                                                     
      LRIR=LFR+NREG                                                       
      LXSRR=LRIR+NREG*ISMAX*NX                                            
      LSIG1=LXSRR+2*NX+1                                                  
      LSEC=LSIG1+NREG                                                     
      LSIGV=LSEC+NREG                                                     
      LP=LSIGV+NREG                                                       
      LPA=LP+NREG*NREG                                                    
      LGAM=LPA+NREG*NREG                                                  
      LYI=LGAM+NREG                                                       
      LXIK=LYI+NREG                                                       
      LXIK2=LXIK+NREG*NREG                                                
      LYI2=LXIK2+NREG*NREG                                                
      LVOLY=LYI2+NREG                                                     
      LFLUQ=LVOLY                                                         
      LFLUJ=LFLUQ+NREG                                                    
      LREMO=LFLUJ+NREG                                                    
      LR=LREMO+NREG                                                       
      LXSC=LR+NX                                                          
      LRIC=LXSC+NX                                                        
      LRC=LRIC+NISO*(2*NX+1)                                              
      LRIZ=LRC+NX*2+1                                                     
      LRIEXA=LRIZ+ISMAX*(2*NX+1)                                          
      LRZ=LRIEXA+NREG*ISMAX*NX                                            
      LRREM=LRZ+2*NX+1                                                    
      LXS3A=LRREM+NREG*ISMAX 
      IOPI91  =IOPI(9)                                                    
      LXS3F=LXS3A+IT10*ISRES                                              
      LXS3S=LXS3F+IT10*ISRES                                              
      LAPP=LXS3S+IT10*ISRES                                                
      NRP=NREG*(NREG+1)/2                                               
      NRP=1                                             
      NIPP=1                                            
      LXIP=LAPP+NRP*NIPP                                                
      LAS=LXIP+NIPP+LAS                                                 
      CALL MEMORI                                                         
C                                                                         
C     Calcul for each case of NCASOS                                 
C                                                                         
      WRITE(IS6,23)
C
      WRITE(IS6,34)
C
      DO ICASO=1,NCASOS                                               
C
       DO I=1,LAS                                                      
        A1(I)=0.0                                                           
       ENDDO
C
       IF(ICASO.GT.1)THEN
C
        WRITE(IS6,35)ICASO
C                                                                         
C       read data for a new case  
C                                                                         
        IF(IOPI(3).EQ.2)THEN                                           
C
C       lambda calc. case  (read increments on atomic densities 
C                           of H if IOPI(6)=0, or of X if IOPI(6)=1)
C
         ND1=1
         ND2=3
         NDD2=ND2
         READ(ID5,*)DELTAD                                                   
         IF(IOPI(6).EQ.0)THEN
          NDD2=2                                              
          WRITE(IS6,36)DELTAD                                                  
         ELSE
          WRITE(IS6,37)DELTAD  
         ENDIF
         DN(ND1,NDD2)=DN(ND1,NDD2)+DELTAD                                    
         WRITE(IS6,38)DN(ND1,NDD2)
C
        ELSE
C
C       no-lambda calc. cases 
C       (read atomic densities of all mats)
C
         WRITE(IS6,1)
         DO I=1,NMAT                                                         
          WRITE(IS6,2)I
          WRITE(IS6,3)ISMA(I)                                                 
          ISMA1=ISMA(I)                                                       
          WRITE(IS6,4)
          WRITE(IS6,5)(ID(I,J),J=1,ISMA1)
          READ(ID5,*) (DN(I,J),J=1,ISMA1)
          WRITE(IS6,6)
          WRITE(IS6,7)(DN(I,J),J=1,ISMA1)
          READ(ID5,*)TEMP(I)                             
          WRITE(IS6,8)TEMP(I)
         END DO                                                           
C
        ENDIF
C
        WRITE(IS6,23)
C
       ENDIF
C                                                                         
C      Calcul of DN or XSB according IOPI(5) (for HOMO and IOPI(3)=1 only)
C                                                                         
       IF(IOPI(1).EQ.0.AND.IOPI(3).EQ.1)THEN
C
        IF(IOPI(5).EQ.1)THEN                                           
C                                                                         
C        XSB is input- calcul DN                                           
C                                                                         
         ND1=1                                                               
         ND2=2                                                               
         XSB=DN(ND1,ND2)                                                     
         DN(ND1,ND2)=(XSB-URLAM*XS22(ND1,NX))*DN(ND1,ND1)/XS22(ND2,NX)       
         WRITE(IS6,39)DN(ND1,ND2)
C
        ELSE
C                                                                         
C        DN is input - calcul XSB                                                        
C                                                                         
         ND1=1                                                               
         ND2=2                                                               
         XSB=XS22(ND1,NX)*URLAM                                              
         XSB=XSB+XS22(ND2,NX)*DN(ND1,ND2)/DN(ND1,ND1)                        
         WRITE(IS6,40)XSB
C  
        ENDIF
C
       ENDIF
C                                                                         
C      Calcul Q0C                                                      
C
       CALL CALQ0C(Q0C,NMAT,NISO,V,ID,XSI,XS22,ISMA,DN,MATR)  
C                                                                         
C      rewind reso XS files  
C                                                                         
       ID11=10                                                             
       DO I=1,ISRES                                                    
        ID11=ID11+1                              
        OPEN(UNIT=ID11,FILE=NOMXS(I),FORM='UNFORMATTED',STATUS='OLD')   
        REWIND ID11                                                         
       ENDDO
C                                                                         
C      initial values                                                    
C                                                                         
       IT11=0
       IGFABS=0                                                            
       IGG=1                                                               
       IGI=1                                                               
       INTER=1                                                             
       PG1=1.0                                                             
       NGF2=1                                                              
       NGF1=NGF(1)                                                         
       INXS=1                                                              
       IGIAN=1                                                             
       NGFI2=1                                                             
       PG=1.0                                                              
       DO IPRI=1,3                                                     
        IPCAL(IPRI)=1                                                       
       ENDDO
C                                                                         
C                                                                         
C      Calcul for each fine group
C                   
C                                                      
       DO IGF=1,NGFT                                                   
C
        IGFABS=IGFABS+1                                                     
C                                                                         
C       Calcul of the source Q                                              
C                                                                         
        CALL FUENTE(NMAT,ISMAX,NREG,NGI,NISO,
     1              SA1   ,UMAX  ,DN    ,XS22  ,MATR  ,ISMA  ,              
     2              C     ,L     ,ID    ,NRES  ,                            
     3              A1(LXSIM)    ,A1(LXSPIM)   ,A1(LQ)       ,              
     4              A1(LXSFI)    ,A1(LFI)                     ) 
C                                                                         
C       Preparation of XS                                   
C                                                                         
        CALL PREPXS(NMAT,ISMAX,NISO,IT10,NGFTOT,IT11,ISRES,
     1              DN    ,IRUB  ,ISMA  ,XS22  ,MATR  ,              
     3              C     ,NRES  ,TEMP  ,ID    ,IFISIO,                     
     4              A1(LXS3A)    ,A1(LXS3F)    ,A1(LXS3S)    ,              
     5              A1(LXSIM)    ,A1(LXS1)     ,A1(LXSGG)    ,
     6              A1(LXST)     ,A1(LXS2)     ,A1(LXSPIM)) 
C                                                                         
C       Calcul of the flux and derived  parameters                             
C                                                                         
        CALL FLUJOS(NREG,NMAT,NGI,ISMAX,ISRES,NRP,                          
     1              V     ,MATR  ,ISMA  ,R1    ,NGF   ,L     ,              
     2              ID    ,NRES  ,R2    ,              
     3              A1(LQ)       ,A1(LXST)     ,A1(LXSGG)    ,              
     4              A1(LFI)      ,A1(LXSR)     ,A1(LRIR)     ,              
     5              A1(LXSIM)    ,A1(LXSFI)    ,A1(LSIG1)    ,              
     6              A1(LSEC)     ,A1(LSIGV)    ,A1(LP)       ,
     7              A1(LGAM)     ,A1(LXIK)     ,A1(LYI)      ,
     8              A1(LVOLY)    ,A1(LFLUQ)    ,A1(LFLUJ)    ,         
     9              A1(LREMO)    ,A1(LRREM)    ,A1(LRIEXA)   ,
     A              A1(LFR)      ,A1(LXSTA)    ,A1(LPA)      ,
     B              A1(LXSTA2)   ,A1(LXSTA3)   ,A1(LXIK2)    ,
     C              A1(LYI2)     ,A1(LAPP)     ,A1(LXIP)      ) 
C                                                                         
        IF(NGFI2.NE.NGFI)THEN
         NGFI2=NGFI2+1                                                       
        ELSE
         NGFI2=1                                                             
         INTER=INTER+1                                                       
         IGIAN=IGI                                                           
         IGI=IGI+1                                                           
        ENDIF
        IF(NGF2.NE.NGF1)THEN                                           
         NGF2=NGF2+1                                                         
        ELSE
C                                                                         
C        output for each broad group
C
          CALL SALIDA(NREG,ISMAX,NMAT,NISO,NCASOS, 
     1                ISMA  ,DUGG  ,DN    ,SIMBO ,MATR  ,NRZ   ,              
     2                ID    ,NRES  ,V     ,TEMP  ,XS22  ,C     ,              
     3                A1(LRIR)     ,A1(LR)       ,A1(LFR)      ,              
     4                A1(LXSC)     ,A1(LRIC)     ,A1(LRC)      ,              
     5                A1(LRREM)    ,A1(LRIZ)     ,A1(LXSRR)    ,              
     6                A1(LRZ)      ,A1(LRIEXA)                  )
C                                                                         
          NGF2=1                                                              
          IGG=IGG+1                                                           
          NGF1=NGF(IGG)                                                       
          IGFABS=0                                                            
        ENDIF
       ENDDO                                                            
      ENDDO
C                                                                         
      RETURN                                                              
      END                                                                 
C      
C     ***************                                                     
C     *             *                                                     
C     * M E M O R I *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
      SUBROUTINE MEMORI                                                    
C                                                                         
      COMMON/A/ ID1,ID2,ID3,ID4,ID5,ID10,IS6,IS7,IS8,IS9                  
C                                                                         
      COMMON/E/L0,LAS                                                 
C
 1    FORMAT(/'GENERAL ARRAY A()'/
     1'AVAILABLE MEMORY =',I8/' REQUIRED =',I8//)                                                               
 2    FORMAT(' THE PROGRAM FINISH. ADD=',I8/,
     1' MORE DIMENSION TO THE GENERAL ARRAY A()'/
     2' AND CHANGE PARAMETER L0 IN MAIN PROGRAM')                                           
 3    FORMAT(' NOT USED DIMENSION OF A() =',I8//)                                           
C
      L=L0-LAS                                                            
C
      IF(L.LT.0)THEN                                                 
       L=-L                                                                
       WRITE(IS6,1)L0,LAS                                                  
       WRITE(IS6,2)L                                                       
       STOP 1                                                              
      ENDIF
C
      WRITE(IS6,1)L0,LAS                                                  
      WRITE(IS6,3)L                                                       
C
      RETURN                                                              
      END                                                                 
C
      SUBROUTINE CALQ0C(Q0C,NMAT,NISO,V,ID,XSI,XS22,ISMA,DN,MATR)       
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * C A L Q 0 C *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
      DIMENSION V(1),ID(NMAT,1),XSI(1),XS22(NISO,1),ISMA(1),
     1          DN(NMAT,1),MATR(1)                        
C
      COMMON/B/ NGG   ,IXXX  ,ISRES ,NRSUM ,NGI   ,NTABXA,                
     1          IXXY  ,NREG  ,NZ    ,ISMAX ,NIRMAX,NX    ,                
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,                
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,                
     4          NGFI2 ,INXS  ,IT10  ,IT62  ,IGIAN ,IM    ,                
     5          IG                                                        
C
      COMMON/D/IOPI(16)                                                   
C
C     calcul of factor Q0C                                 
C                                                                         
      IM1=1                                                             
      Q0C=0.0                                                             
C
      DO I=1,NREG                                                     
c
       IF(IOPI(1).EQ.1)IM1=MATR(I)              
       IS1=ISMA(IM1)                                                       
       IF(IOPI(1).EQ.0)V(I)=1.0                                            
C
       DO J=1,IS1                                                      
        ID1=ID(IM1,J)                                                       
        Q0C=Q0C+XSI(ID1)*XS22(ID1,NX)*DN(IM1,J)*V(I)                        
       ENDDO
C
      ENDDO
C
      RETURN                                                              
      END                                                                 
C                         
      SUBROUTINE PARENE(NGF,DUGG)                                         
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * P A R E N E *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     calcul of energy parameters
C                                                                         
      DIMENSION NGF(1),DUGG(1)                                            
      COMMON/B/ NGG   ,NISO  ,ISRES ,NRSUM ,NGI   ,NTABXA,                
     1          NMAT  ,NREG  ,NZ    ,ISMAX ,NIRMAX,NX    ,                
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,                
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,                
     4          NGFI2 ,INXS  ,IT10  ,IT62  ,IGIAN ,IM    ,                
     5          IG                                                        
C                                                                         
      COMMON/C/ EMAX  ,DUGF  ,ALBEDO,AJEXT ,ANUFIS,URLAM ,                
     1          DUGI  ,SA    ,SB    ,SD    ,RE2SM ,VTOT  ,                
     2          PG    ,U     ,U3    ,Q0C   ,E22   ,EM    ,                
     3          SA1MIN,PG1   ,XSB   ,PERCON,SCOP  ,DXST(3),EMAR           
C                                                                         
C     Number of fine groups                                         
C                                                                         
      NGFT=0                                                              
      DO I=1,NGG                                                       
       NGFT=NGFT+NGF(I)                                                    
      ENDDO
C                                                                         
C     lethargy width of intermediate groups                                         
C                                                                         
      DUGI=FLOAT(NGFT)*DUGF/FLOAT(NGI)                                    
C                                                                         
C     Factors for calcul of source Q                                
C                                                                         
      SA=EXP(-DUGF)                                                       
      SB=(SA-1.0)*(SA-1.0)/DUGF                                           
      SD=(SA+DUGF-1.0)/DUGF                                               
C                                                                         
C     lethargy widths of broad groups
C                                                                         
      DO I=1,NGG                                                      
       NGF1=NGF(I)                                                         
       DUGG(I)=FLOAT(NGF1)*DUGF                                            
      ENDDO
C                                                                         
C     Factor for calcul of background abs and fis XS             
C                                                                         
      RE2SM=SQRT(E22/EMAX)                                                
C                                                                         
C     Number of fine groups x intermediate group                         
C                                                                         
      NGFI=NGFT/NGI                                                       
C
      RETURN                                                              
      END                                                                 
C      
      SUBROUTINE PARISO(NISO,C,L,XSI,XS22,UMAX,SA1)                       
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * P A R I S O *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     calcul of isotope parameters                        
C                                                                         
      COMMON/B/ NGG   ,IXXX  ,ISRES ,NRSUM ,NGI   ,NTABXA,                
     1          NMAT  ,NREG  ,NZ    ,ISMAX ,NIRMAX,NX    ,                
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,                
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,                
     4          NGFI2 ,INXS  ,IT10  ,IT62  ,IGIAN ,IM    ,                
     5          IG                                                        
C                                                                         
      COMMON/C/ EMAX  ,DUGF  ,ALBEDO,AJEXT ,ANUFIS,URLAM ,                
     1          DUGI  ,SA    ,SB    ,SD    ,RE2SM ,VTOT  ,                
     2          PG    ,U     ,U3    ,Q0C   ,E22   ,EM    ,                
     3          SA1MIN,PG1   ,XSB   ,PERCON,SCOP  ,DXST(3),EMAR           
C                                                                         
      DIMENSION C(1),L(1),XSI(1),XS22(NISO,1),UMAX(1),SA1(1)              
C                                                                         
      SA1MIN=1.0E-15                                                      
C                                                                         
      DO I=1,NISO                                                     
C
       IF(C(I).GT.1.1)THEN                                            
C
        EPS9=1.0+2.0/(C(I)-1.0)                                             
        EPS10=2.0*ALOG(EPS9)                                                
        L(I)=EPS10/DUGF                                                     
        ALFA1=(C(I)-1.0)/(C(I)+1.0)                                         
        ALFA=ALFA1*ALFA1                                                    
        C(I)=1.0/(1.0-ALFA)                                                 
        XSI(I)=1.0+ALOG(ALFA)*(ALFA/(1.0-ALFA))                             
C
       ELSE                                                
C
        C(I)=1.0                                                            
        L(I)=NGFT+1000                                                      
        XSI(I)=1.0                                                          
C
       ENDIF
C
       DO J=1,NX1                                                      
        XS22(I,J)=XS22(I,J)*RE2SM                                           
       ENDDO
C
       UMAX(I)=DUGF*FLOAT(L(I)+1)                                          
       SA1(I)=1.0                                                          
       L1=L(I)-1                                                           
C
       IF(C(I).GE.1.1)THEN
        DO IJ=1,L1                                                      
         SA1(I)=SA1(I)*SA                                                    
         IF(SA1(I).LT.SA1MIN)SA1(I)=0.0                                       
        ENDDO
       ELSE
        SA1(I)=0.0                                                          
       ENDIF
C
      ENDDO
C                                                                         
      RETURN                                                              
      END                                                                 
C
C     ***************                                                     
C     *             *                                                     
C     * P R E P X S *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     preparation of XS for calcul             
C                                                                         
      SUBROUTINE PREPXS(NMAT,ISMAX,NISO,IT10,NGFTOT,IT11,ISRES,
     1                  DN    ,IRUB  ,ISMA  ,XS22  ,MATR  ,        
     3                  C     ,NRES  ,TEMP  ,ID    ,IFISIO,
     4                  XS3A  ,XS3F  ,XS3S  ,XSIM  ,XS1   ,XSGG  ,
     5                  XST   ,XS2   ,XSPIM)                       
C                                                                         
      DIMENSION DN(NMAT,1)  ,IRUB(1)     ,ISMA(1)     ,XS22(NISO,1),
     1          MATR(1)     ,C(1)        ,NRES(1)     ,TEMP(1)     ,      
     2          ID(NMAT,1)  ,XS3A(IT10,1),XS3F(IT10,1),
     3          XS3S(IT10,1),XSIM(NMAT,ISMAX,1)       ,XS1(1)    ,
     4          XSGG(1)     , XST(1)      ,XS2(1)      ,
     5          XSPIM(NMAT,ISMAX)        ,X1(10),IFISIO(ISRES)               
C                                                                         
      COMMON/A/ ID1, ID2 ,ID3 ,ID4 ,ID5 ,ID10,                            
     1          IS6 ,IS7 ,IS8 ,IS9                                        
C                                                                         
      COMMON/B/ NGG   ,NXX1  ,NZZ1 ,NRSUM ,NGI   ,NTABXA,                
     1          NXX2  ,NREG  ,NZ    ,NXX5 ,NIRMAX,NX    ,                 
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,                
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,                
     4          NGFI2 ,INXS  ,NXX7  ,NXX8  ,IGIAN ,IM    ,                
     5          IG                                                        
C                                                                         
      COMMON/C/ EMAX  ,DUGF  ,ALBEDO,AJEXT ,ANUFIS,URLAM ,                
     1          DUGI  ,SA    ,SB    ,SD    ,RE2SM ,VTOT  ,                
     2          PG    ,U     ,U3    ,Q0C   ,E22   ,EM    ,                
     3          SA1MIN,PG1   ,XSB   ,PERCON,SCOP  ,DXST(3),EMAR           
C                                                                         
      COMMON/D/ IOPI(16)                                                  
C                                                                         
      COMMON/G/I0I(10),IPCAL(3)                                           
C
      CHARACTER*3 NOMXS(9)
C                                                                         
C
C
      IAPER=0                                                           
      IAA=1                                                               
      IFF=2                                                               
      ISS=3                                                               
C                                                                         
C     open XS files
C                                                                         
      IAR=10                                                              
      ID11=10                                                             
      EM=EXP(U3)                                                          
      INXSS=1                                                             
C
      IF(IGF.EQ.1.OR.IGF.EQ.(IT10*IT11+1))THEN
C
       IF(IGF.EQ.1)IT11=0
       NOMXS(1)='XS1'                                                    
       NOMXS(2)='XS2'                                                    
       NOMXS(3)='XS3'                                                    
       NOMXS(4)='XS4'                                                    
       NOMXS(5)='XS5'                                                    
       NOMXS(6)='XS6'                                                    
       NOMXS(7)='XS7'                                                    
       NOMXS(8)='XS8'                                                    
       NOMXS(9)='XS9'                                                    
       IT11=IT11+1
C
       DO IS=1,NISO
C      
        NR=NRES(IS)    
C                                                     
        IF(NR.EQ.1)THEN                                                
C                                                                         
C       read reso XS's 
C       
         ID11=IS+10.01
C
         IF(IGF.EQ.1)THEN
C
C         OPEN(UNIT=ID11,FILE=NOMXS(IS),FORM='UNFORMATTED',STATUS='OLD')
C
          READ(ID11)NNN,IFISIO(IS),NNNN
          READ(ID11)DDD
          READ(ID11)EMMM
C
         ENDIF
C
         READ(ID11)(XS3A(II,IS),II=1,IT10)
         READ(ID11)(XS3S(II,IS),II=1,IT10)
         IF(IFISIO(IS).EQ.1)READ(ID11)(XS3F(II,IS),II=1,IT10)
         IF(IFISIO(IS).EQ.0)THEN
          DO II=1,IT10
           XS3F(II,IS)=0.0
          ENDDO
         ENDIF
         IF(NGFTOT.EQ.IT10*IT11)CLOSE(ID11)
        ENDIF
C
       ENDDO
C           
      ENDIF                                                              
C
C     Obtention of XS for each material                                  
C                                                                         
      DO I=1,NMAT                                                     
C
       NI=ISMA(I)                                                          
C
       DO J=1,NI                                                       
C
        INDIC=1                                                           
        IS=ID(I,J)                                                          
        NR=NRES(IS)    
C                                                     
        IF(NR.EQ.1)THEN                                                
C
         IAA=1                                                               
         IFF=2                                                               
         ISS=3                                                               
         IT12=IGF-IT10*(IT11-1)
         XS2(IAA)=XS3A(IT12,IS)                                              
         XS2(IFF)=XS3F(IT12,IS)                                              
         XS2(ISS)=XS3S(IT12,IS)                                              
C                                                                         
C        mac XS's of reso isotopes                              
C                                                                         
         DO K11=1,NX                                                     
          XSIM(I,J,K11)=XS2(K11)*DN(I,J)                                      
         ENDDO
C
        ELSE
C                                                                         
C       mac XS's of no-reso isotopes                           
C                                                                         
         DO K12=1,NX1                                                    
          XSIM(I,J,K12)=XS22(IS,K12)*DN(I,J)*EM                               
         ENDDO
C
         XSIM(I,J,NX)=XSPIM(I,J)                                             
C
        ENDIF
C
       ENDDO
C
      ENDDO                                                            
C                                                                         
C     Preparation of XS's for each region (total and self-scattering)     
C                                                                         
      IM=1                                                              
      DO I=1,NREG                                                     
C
       XSGG(I)=0.0                                                         
       XST(I)=0.0                                                          
       IF(IOPI(1).EQ.1)IM=MATR(I)                                                          
       NI=ISMA(IM)                                                         
C
       DO J=1,NI                                                       
C
        IS=ID(IM,J)                                                         
C                                                                         
C       Factor for self-scattering XS                                    
C                                                                         
        XSGG(I)=XSGG(I)+C(IS)*XSIM(IM,J,NX)                                 
C                                                                         
C       total XS                                                             
C                                                                          
        XST(I)=XST(I)+XSIM(IM,J,IAA)+XSIM(IM,J,NX)                          
C
       ENDDO
C                                                                         
C      self-scattering XS                                                
C                                                                         
       XSGG(I)=XSGG(I)*SD                                                  
C
      ENDDO
C                                                                         
      RETURN                                                              
      END                                                                 
C
C     ***************                                                     
C     *             *                                                     
C     * F U E N T E *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     calcul of source Q for each region                  
C                                                                         
      SUBROUTINE FUENTE(NMAT,ISMAX,NREG,NGI,NISO,
     1                  SA1   ,UMAX  ,DN    ,XS22  ,MATR  ,ISMA  ,        
     2                  C     ,L     ,ID    ,NRES  ,
     3                  XSIM  ,XSPIM ,Q     ,XSFI  ,FI            ) 
C                                                                         
      DIMENSION SA1(1)      ,UMAX(1)    ,DN(NMAT,1)  ,XS22(NISO,1),       
     1          MATR(1)     ,ISMA(1)    ,C(1)        ,L(1)        ,       
     2          ID(NMAT,1)  ,NRES(1)    ,
     3          XSIM(NMAT,ISMAX,1)      ,XSPIM(NMAT,1),
     4          Q(1)        ,XSFI(NREG,NGI,1),FI(1)     
C
      COMMON/A/ ID1, ID2 ,ID3 ,ID4 ,ID5 ,ID10,                            
     1          IS6 ,IS7 ,IS8 ,IS9                                        
C                                                                         
      COMMON/B/ NGG   ,NXX1  ,ISRES ,NRSUM ,NXX3  ,NTABXA,                
     1          NXX2  ,NXX4  ,NZ    ,NXX5 ,NIRMAX,NX    ,                 
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,                
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,                
     4          NGFI2 ,INXS  ,IT10  ,NXX6  ,IGIAN ,IM    ,                
     5          IG                                                        
C                                                                         
      COMMON/C/ EMAX  ,DUGF  ,ALBEDO,AJEXT ,ANUFIS,URLAM ,                
     1          DUGI  ,SA    ,SB    ,SD    ,RE2SM ,VTOT  ,                
     2          PG    ,U     ,U3    ,Q0C   ,E22   ,EM    ,                
     3          SA1MIN,PG1   ,XSB   ,PERCON,SCOP  ,DXST(3),EMAR           
C                                                                         
      COMMON/D/ IOPI(16)                                                  
C                                                                         
      COMMON/G/I0I(10),IPCAL(3)                                         
C
C   2  FORMAT(I3,I9,1P4E12.5)                                            
C                                                                         
      IF(IGF.EQ.1)THEN                                               
C                                                                         
C     initial calculs (for the first fine group)                      
C                                                                         
       U=DUGF                                                              
       IOPI91=IOPI(9)                                                      
C                                                                         
C      potential XS of each isotope on each material                       
C                                                                         
       DO I=1,NMAT                                                      
        NI=ISMA(I)                                                          
        DO J=1,NI                                                        
         IS=ID(I,J)                                                          
         XSPIM(I,J)=DN(I,J)*XS22(IS,NX)                                      
        ENDDO
       ENDDO
C                                                                         
C      Calcul of Q initial                                               
C                                                                         
       DO I=1,NREG                                                      
        Q(I)=0.0                                                            
       ENDDO
C
       K=1
C                                                                 
       DO I=1,NREG                                                     
        IF(IOPI(1).EQ.1)K=MATR(I)                                                           
        K1=ISMA(K)                                                          
        DO I1=1,K1                                                       
         Q(I)=Q(I)+XSPIM(K,I1)                                               
        ENDDO
       ENDDO
C
      ELSE
C                                                                         
C     Calcul of Q for non-first fine groups                
C
        K=1                                                                 
C
        DO I=1,NREG                                                     
C                                                                         
C        first term                                                      
C                                                                         
         Q(I)=Q(I)*SA                                                        
         IF(IOPI(1).EQ.1)K=MATR(I)                                                           
         K1=ISMA(K)                                                          
C
         DO J=1,K1                                                       
C
          JJ=ID(K,J)                                                          
C                                                                         
C         second term                                                     
C                                                                         
          Q(I)=Q(I)+SB*C(JJ)*XSIM(K,J,NX)*FI(I)                               
C                                                                         
C         thirth term                                                      
C                                                                         
C         Comparation of present and max lethargy                      
C                                                                         
          Q1=U-UMAX(JJ)                                                       
C
          IF(Q1.GT.0.0)THEN                                              
C
           LM=Q1/DUGI                              
           M=LM+1                                                       
           Q11=FLOAT(LM)*DUGI                                                 
           IF(Q11.EQ.Q1)M=M-1                                                 
C
           IF(M.GT.NGI)THEN                                                  
C            WRITE(IS6,2)JJ,M,Q11,Q1,U,UMAX(JJ)                               
            M=NGI         
           ENDIF                                                             
C                                                                         
C          no-zero intermedate group                                   
C                                                                         
           Q(I)=Q(I)-SB*C(JJ)*SA1(JJ)*XSFI(I,M,J)                              
C
          ELSE
C                                                                         
C          zero-intermediate group               
C
           Q(I)=Q(I)-SB*C(JJ)*SA1(JJ)*XSPIM(K,J)                               
C
          ENDIF
C
         ENDDO
C
        ENDDO
C
      ENDIF
C
      U3=U-DUGF/2.0                                                       
C                                                                         
      RETURN                                                              
      END                                                                 
C
C     ***************                                                     
C     *             *                                                     
C     * F L U J O S *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     calcul of flux for each fine energy group                
C                                                                         
      SUBROUTINE FLUJOS(NREG,NMAT,NGI,ISMAX,ISRES,NRP,                    
     1                  V     ,MATR  ,ISMA  ,R1    ,NGF   ,L     ,        
     2                  ID    ,NRES  ,R21   , 
     3                  Q     ,XST   ,XSGG  ,FI    ,XSR   ,RIR   ,
     4                  XSIM  ,XSFI  ,SIG1  ,SEC   ,SIGV  ,P     ,
     5                  GAM   ,XIK   ,YI    ,VOLY  ,FLUQ  ,FLUJ  ,
     6                  REMO  ,RREM  ,RIEXA ,FR    ,XSTA  ,PA    ,
     7                  XSTA2 ,XSTA3 ,XIK2  ,YI2   ,APP   ,XIP    ) 
C
      DIMENSION V(1)        ,MATR(1)     ,ISMA(1)     ,R1(1)       ,      
     1          NGF(1)      ,L(1)        ,ID(NMAT,1)  ,NRES(1)     ,      
     2          R21(1)      ,
     3          Q(1)        ,XST(1)      ,XSGG(1)     ,FI(1)       ,      
     4          XSR(1)      ,RIR(NREG,ISMAX,1)        ,      
     5          XSIM(NMAT,ISMAX,1)       ,XSFI(NREG,NGI,1)         ,      
     6          SIG1(1)     ,SEC(1)      ,SIGV(1)     ,P(NREG,1)   ,      
     7          GAM(1)      ,XIK(NREG,1) ,YI(1)       ,VOLY(1)     ,      
     8          FLUQ(1)     ,FLUJ(1)     ,REMO(1)     ,      
     9          RREM(NREG,1),RIEXA(NREG,ISMAX,1)      ,FR(1)       ,
     A          XSTA(1)     ,PA(NREG,1)  ,XSTA2(1)    ,XSTA3(1)    ,
     B          XIK2(NREG,1),YI2(1)      ,APP(NRP,1)  ,XIP(1) 
C
      COMMON/A/ ID1, ID2 ,ID3 ,ID4 ,ID5 ,ID10,                            
     1          IS6 ,IS7 ,IS8 ,IS9                                        
C                                                                         
      COMMON/B/ NGG   ,NISO  ,NXX9 ,NRSUM ,NXX3  ,NTABXA,                 
     1          NXX2  ,NXX4  ,NZ    ,NXX5  ,NIRMAX,NX    ,                
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,                
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,                
     4          NGFI2 ,INXS  ,IT10  ,IT62  ,IGIAN ,IM    ,                
     5          IG                                                        
C                                                                         
      COMMON/C/ EMAX  ,DUGF  ,ALBEDO,AJEXT ,ANUFIS,URLAM ,                
     1          DUGI  ,SA    ,SB    ,SD    ,RE2SM ,VTOT  ,                
     2          PG    ,U     ,U3    ,Q0C   ,E22   ,EM    ,                
     3          SA1MIN,PG1   ,XSB   ,PERCON,SCOP  ,DXST(3),EMAR           
C                                                                         
      COMMON/D/ IOPI(16)                                                  
C                                                                         
      COMMON/G/I0I(10),IPCAL(3)                                         
C                                                                         
      COMMON/AB/NIPP                                                    
C                                                                       
  1   FORMAT(10E12.5)                                                      
C                                                                       
  3   FORMAT('FLUX OF THE FIRST FINE GROUP OF EACH INTERMEDIATE GROUP'/
     1' E(eV)       FLUX(I),I=1,NREG'/)                           
C                                                                       
C
C     removal XS - homogeneous case (fine groups)                   
C                                                                         
      IF(IOPI(1).EQ.0)THEN                                            
C
       XSR(1)=XST(1)                                                       
       XSR(1)=XST(1)-XSGG(1)                                               
C                                                                         
C     Flux for homogeneous case                                           
C                                                                         
       FI(1)=Q(1)/XSR(1)                                                   
C
      ELSE
C                                                                         
C      Flux for heterogeneous case                                         
C                                                                         
       CALL PROCO1(ALBEDO,AJEXT,NREG,IG,VTOT,PERCON,NRP,SCOP,IGF,
     1             R1    ,V    ,XST ,XSGG   ,XSR   ,SIG1  ,              
     2             SEC   ,SIGV ,P   ,GAM    ,XIK   ,YI    ,              
     3             Q     ,VOLY ,FLUQ,FLUJ   ,FI    ,REMO  ,              
     4             R21   ,XSTA ,PA  ,DXST   ,XSTA2 ,XSTA3 ,
     5             XIK2  ,YI2  ,APP ,XIP                         )
C
      ENDIF
C
      IF(IOPI(12).EQ.1)THEN                                                     
C
C      write E,FI of first fine group for each intermediate group     
C                                     
       IF((IGF.EQ.1).OR.(NGFI2.EQ.NGFI))THEN
C
        ENER=EMAX*EXP(-U)    
C
        IF(IGF.EQ.1)THEN                                                  
         OPEN(UNIT=IS7,FILE='FIS7.OUT',FORM='FORMATTED',STATUS='NEW')      
         WRITE(IS7,3)                                                        
        END IF                                                            
C
        WRITE(IS7,1)ENER,XST(1),(FI(I)*DUGF,I=1,NREG)                              
C
       ENDIF
      ENDIF
C***************************************************************
C                                                                         
C      Calcul of macrosc.reaccion rates and removal-XS's for broad groups
C                                                                         
       RIA=0.0                                                             
C
       DO I=1,NREG                                                     
C
        IF(IGF.EQ.1)FR(I)=0.0                                               
        FR(I)=FR(I)+FI(I)                                                   
        IF(IOPI(1).EQ.1)IM=MATR(I)                                                          
        NI=ISMA(IM)                                                         
C
        DO J=1,NI                                                        
         JJ=ID(IM,J)                                                         
         IF(IGF.EQ.1)XSFI(I,IGI,J)=0.0                                       
C
         DO K=1,NX1                                                       
          IF(IGF.EQ.1)RIR(I,J,K)=0.0                                          
          RIR(I,J,K)=RIR(I,J,K)+XSIM(IM,J,K)*FI(I)                            
         ENDDO                                                            
C
         IF(IGF.EQ.1)RIR(I,J,NX)=0.0                                         
         XF=XSIM(IM,J,NX)*FI(I)                                              
         RIR(I,J,NX)=RIR(I,J,NX)+XF                                          
         IAA=1                                                               
         RIA=RIA+XSIM(IM,J,IAA)*FI(I)*V(I)                                   
         XSFI(I,IGI,J)=XSFI(I,IGI,J)+XF/NGFI                                 
         IF(IGF.EQ.1)RREM(I,J)=0.0                                           
         IDEL=NGF(IGG)-IGFABS                                                
         LJJ=L(JJ)                                                           
         NN=AMIN0(IDEL,LJJ)                                                  
         F1=SA**(NN+1)                                                       
         SUMP=1.0+(F1-1)/(SA-1.0)                                            
         RREM(I,J)=RREM(I,J)+XF*SUMP                                         
C
        ENDDO
C
       ENDDO
C
C
      U=FLOAT(IGF+1)*DUGF                                                 
C                                                                         
      RETURN                                                              
      END                                                                 
C************************************************************************
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * P R O C O 1 *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     calcul of flux in cylindrical geometry              
C     with collision probability method                       
C                                                                         
      SUBROUTINE PROCO1 (ALBEDO,AJEXT,NREG,IG,VTOT ,SB,NRP,SCOP,IGF,
     1                   R    ,V   ,XST  ,XSGG,XSR ,SIG1 ,SEC ,
     2                   SIGV ,P   ,GAM  ,           
     3                   XIK  ,YI   ,Q   ,VOLY,FLUQ,FLUJ ,FI  ,
     4                   REMO ,R21  ,XSTA,PA  ,DXST,XSTA2,XSTA3,
     5                   XIK2 ,YI2  ,APP ,XIP                       )
C                                                                         
      DIMENSION    R(1),     V(1),     XST(1),   XSGG(1),  XSR(1),        
     1             SIG1(1),  SEC(1),   SIGV(1),  P(NREG,1),GAM(1),
     2             XIK(NREG,1),        YI(1),    Q(1),     VOLY(1),  
     3             FLUQ(1),  FLUJ(1),  FI(1),    REMO(1),  R21(1),       
     4             XSTA(1),  PA(NREG,1),         DXST(3),  XSTA2(1), 
     5             XSTA3(1), XIK2(NREG,1),       YI2(1),   APP(NRP,1),
     6             XIP(1)                                          
C                                                                         
      COMMON/G/I0I(10),IPCAL(3)                                           
C                                                                         
      COMMON/CPR001/NIN,NOT,NX1(2)                                        
C                                                                         
      COMMON /CPR002/ IXX1,IXX2,NX203,XX3,XX4,NX206                       
C
      COMMON/A/ ID1, ID2 ,ID3 ,ID4 ,ID5 ,ID10,                            
     1          IS6 ,IS7 ,IS8 ,IS9                                        
C
      COMMON/AB/NIPP                                                    
C
C                                                                       
      IXX1=NREG                                                           
      IXX2=IG                                                             
      XX3=VTOT                                                            
      XX4=SB                           
C                                   
C     data preparation                                                       
C                                                                         
      CALL PREPAR (R, V, XST, XSGG, XSR, SIG1, SEC, SIGV)
C                                                                         
C     Calcul of collision probabilities                                
C
      CALL COPRAN(NREG,IG,NRP,SCOP,
     1            R,XST,P,GAM,R21,SIGV,APP,XIP)          
C
       IF(I0I(9).EQ.0)THEN                                           
        CALL GAUSCP(NREG,SEC,SIG1,SIGV,P,PA,GAM,XIK,YI)                     
       ELSE
        CALL GAUSDP(NREG,SEC,SIG1,SIGV,P,PA,FI,Q,GAM)                   
       ENDIF
C  
       IF(I0I(9).EQ.0)THEN                                          
C
        CALL CALFLU(NREG,ALBEDO,AJEXT,
     1              V   ,XSR   ,YI   ,XIK ,Q ,VOLY ,FLUQ , FLUJ,        
     2              FI  ,REMO  ,XIK2 ,YI2                       ) 
C
       ENDIF
C
      RETURN                                                              
      END                                                               
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * P R E P A R *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     data preparation for flux calculation for cylindrical geometry            
C                                                                         
      SUBROUTINE PREPAR (R, V, XST, XSGG, XSR, SIG1, SEC, SIGV)    
C                                                                         
      DIMENSION  R(1)   , V(1)  , XST(1) ,  XSGG(1),  XSR(1),        
     1           SIG1(1), SEC(1), SIGV(1)         
C                                                                         
      COMMON /CPR001/ NIN,NOT,NX1(2)                                      
c
      COMMON /CPR002/ NREG,IG,NX203,VTOT,SB,NX206                         
C                                                                         
      DATA SMALL /1.0E-08/                                                
C                                                                         
      DO M=1,NREG                                            
       XSR(M)=XST(M) - XSGG(M)                                             
       XST(M)=XST(M) + SMALL                                               
       SIG1(M)=1.0/XST(M)                                                  
       SEC(M)=XSGG(M)*SIG1(M)                                              
       SIGV(M)=XST(M)*V(M)                                                 
      ENDDO
C
      RETURN                                                              
      END                                                                 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * C O P R A N *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     calcul of collision probabilities for cylindrical geometry       
C                                                                         
      SUBROUTINE COPRAN (MMAX,IG,NRP,SCOP,
     1                   R ,SIG ,P ,GAM ,R2 ,SIGV ,APP ,XIP)
C                                                                         
      REAL KI3                                                       
C
      DIMENSION R(1)      ,SIG(1),P(MMAX,1),GAM(1)  ,R2(1),SIGV(1),
     1          APP(NRP,1),XIP(1),         
     2          GJC(36),GJP(6,6) ,GJW(6,6) ,TAU(100),TX(100)                 
C
      COMMON/G/I0I(10),IPCAL(3)                                         
C                                                                         
      EQUIVALENCE (GJC(1),GJP(1,1),GJW(1,1)),(TX(2),TAU(1))               
C                                                                         
      DATA      GJC                                                       
     1 /.00000000,.55555556,.87393877,.95491150,.98046718,.99029084,      
     2 2.00000000,.00000000,.28606124,.65127016,.82660307,.90725799,      
     3  .72783448,1.27216552,.0000000,.16932809,.47704397,.68412769,      
     4  .27930792,.91696442,.80372766,.00000000,.11094751,.35681753,      
     5  .12472388,.51939018,.81385828,.54202764,.00000000,.07803490,      
     6  .06299166,.29563548,.58554794,.66869856,.38712636,.00000000/      
C                                                                         
      N=MMAX                                                              
C
      DO 10 I=1,N                                                         
      DO 10 J=I,N                                                         
 10   P(I,J)=0.0                                                          
C                                                                         
       DO 20 I=1,N                                                         
       RSTART=0.0                                                          
       IF(I.GT.1) RSTART=R(I-1)                                            
       DR=R(I)-RSTART                                                      
       DO 20 K=1,IG                                                        
       Y=RSTART+DR*GJP(IG+1,K)                                             
       FAC=DR*GJW(K,IG+1)                                                  
       TAU(I-1)=0.0                                                        
       TPLUS=0.0                                                           
       Y2=Y*Y                                                              
       DO 20 J=I,N                                                         
       TMINUS=TPLUS                                                        
       TPLUS=SQRT(R2(J)-Y2)                                                
       TAU(J)=TAU(J-1)+SIG(J)*(TPLUS-TMINUS)                               
       DO 20 L=I,J                                                         
 20    P(L,J)=P(L,J)+FAC*(KI3(TAU(J)+TAU(L))-KI3(TAU(J)-TAU(L)))           
C                                                                         
       DO I=1,N                                                         
C
        J=N-I+1                                                             
        DO 30 K=J,N                                                         
        L=J+N-K                                                             
        IF(L.EQ.1) GO TO 30                                                 
        IF(L.EQ.J) P(J,L-1)=P(L-1,J)                                        
        P(J,L)=P(J,L)-P(J,L-1)                                              
        IF(J.EQ.1) GO TO 30                                                 
        P(J,L)=P(J,L)-P(J-1,L)+P(J-1,L-1)                                   
 30     P(L,J)=P(J,L)                                                       
        P(J,J)=P(J,J)+SIGV(J)                                               
C
       ENDDO
C                                                                         
      DO I=1,N                                                         
C
       SUM=SIGV(I)                                                         
C
       DO J=1,N                                                         
        SUM=SUM-P(I,J)                                                      
       ENDDO
C
       IF(I0I(9).EQ.1)SCOP=1.0                                           
       GAM(I)=SCOP*SUM                                                     
C
      ENDDO
C                                                                         
      IF(I0I(9).EQ.1)THEN                                           
C
       SUMGAM=0.0                                                        
C
       DO I=1,MMAX                                                    
        SUMGAM=SUMGAM+GAM(I)                                              
       ENDDO
C
       DO J=1,MMAX                                                   
C
        DO 90 I=1,MMAX                                                    
 90     P(I,J)=P(I,J)+GAM(I)*GAM(J)/SUMGAM                                
C
       ENDDO
C
      ENDIF
C                                               
      RETURN                                                              
      END                                                                 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                          
C     *********                                                            
C     *       *                                                            
C     * K I 3 *                                                            
C     *       *                                                            
C     *********                                                            
C                                                                          
C     Function Ki3, for calcul of collision probabilities            
C     in cylindrical geometry                                              
C                                                                          
C     Exactness: 1.0e-5, until XX=9.0                                      
C                                                                          
      REAL FUNCTION KI3(XX)                                                
C
      X=ABS(XX)                                                            
C
      IF(X.GT.0.999999) GO TO 16                                           
C
      I=IFIX(20.0*X+1.000001)                                              
      GO TO (1,2,3,4,5,6,7,8,9,10,11,11,12,12,13,13,14,14,15,15),I         
      RETURN                                                               
C                            ** Range 0.00-0.05 **                         
1     KI3=(.7266088*X-.9990226)*X+.7853961                                 
C                            ** Range 0.05-0.10 **                         
2     KI3=(.6466375*X-.9912340)*X+.7852024                                 
      RETURN                                                               
C                            ** Range 0.10-0.15 **                         
3     KI3=(.5856605*X-.9791293)*X+.7845986                                 
      RETURN                                                               
C                            ** Range 0.15-0.20 **                         
4     KI3=(.5346648*X-.9638914)*X+.7834577                                 
      RETURN                                                               
C                            ** Range 0.20-0.25 **                         
5     KI3=(.4907827*X-.9463843)*X+.7817094                                 
      RETURN                                                               
C                            ** Range 0.25-0.30 **                         
6     KI3=(.4521752*X-.9271152)*X+.7793031                                 
      RETURN                                                               
C                            ** Range 0.30-0.35 **                         
7     KI3=(.4177388*X-.9064822)*X+.7762107                                 
      RETURN                                                               
C                            ** Range 0.35-0.40 **                         
8     KI3=(.3869945*X-.8849865)*X+.7724519                                 
      RETURN                                                               
C                            ** Range 0.40-0.45 **                         
9     KI3=(.3590753*X-.8626685)*X+.7679903                                 
      RETURN                                                               
C                            ** Range 0.45-0.50 **                         
10    KI3=(.3338676*X-.8400133)*X+.7628988                                 
      RETURN                                                               
C                            ** Range 0.50-0.60 **                         
11    KI3=(.2998569*X-.8054172)*X+.7540982                                 
      RETURN                                                               
C                            ** Range 0.60-0.70 **                         
12    KI3=(.2609154*X-.7587821)*X+.7401279                                 
      RETURN                                                               
C                            ** Range 0.70-0.80 **                         
13    KI3=(.2278226*X-.7125290)*X+.7239594                                 
      RETURN                                                               
C                            ** Range 0.80-0.90 **                         
14    KI3=(.1994999*X-.6672761)*X+.7058777                                 
      RETURN                                                               
C                            ** Range 0.90-1.00 **                         
15    KI3=(.1751248*X-.6234536)*X+.6861762                                 
      RETURN                                                               
C
16    IF(X.GT.9.0) GO TO 160                                               
C
      I=IFIX(2.5*(X-0.999998))+1                                           
      GO TO (17,18,19,20,21,22,23,24,25,26,                                
     1       27,27,28,28,29,29,30,30,31,31,31),I                           
C
160   KI3=0.0                                                              
      RETURN                                                               
C                            ** Range 1.0-1.4 **                           
17    KI3=((-.05337485*X+.3203223)*X-.7538355)*X+.7247294                  
      RETURN                                                               
C                            ** Range 1.4-1.8 **                           
18    KI3=((-.03146833*X+.2295280)*X-.6279752)*X+.6663720                  
      RETURN                                                               
C                            ** Range 1.8-2.2 **                           
19    KI3=((-.01906198*X+.1631667)*X-.5094124)*X+.5956163                  
      RETURN                                                               
C                            ** Range 2.2-2.6 **                           
20    KI3=((-.01174752*X+.1152418)*X-.4046007)*X+.5191031                  
      RETURN                                                               
C                            ** Range 2.6-3.0 **                           
21    KI3=((-.007328415*X+.08097913)*X-.3159648)*X+.4425954                
      RETURN                                                               
C                            ** Range 3.0-3.4 **                           
22    KI3=((-.004617254*X+.05669960)*X-.2434341)*X+.3703178                
      RETURN                                                               
C                            ** Range 3.4-3.8 **                              
23    KI3=(.007923547*X-.07158569)*X+.1684022                              
      RETURN                                                               
C                            ** Range 3.8-4.2 **                           
24    KI3=(.005095111*X-.05016344)*X+.1278307                              
      RETURN                                                               
C                            ** Range 4.2-4.6  **                          
25    KI3=(.003286040*X-.03501524)*X+.09611422                             
      RETURN                                                               
C                            ** Range 4.6-5.0 **                           
26    KI3=(.002126242*X-.02437465)*X+.07170491                             
      RETURN                                                               
C                            ** Range 5.0-5.8 **                           
27    KI3=(.001123687*X-.01425519)*X+.04616317                             
      RETURN                                                               
C                            ** Range 5.8-6.6 **                           
28    KI3=(4.762937E-4*X-6.810124E-3)*X+.02475115                          
      RETURN                                                               
C                            ** Range 6.6-7.4 **                           
29    KI3=(2.031843E-4*X-3.232035E-3)*X+.01302864                          
      RETURN                                                               
C                            ** Range 7.4-8.2 **                           
30    KI3=(8.701440E-5*X-1.524126E-3)*X+6.749972E-3                        
      RETURN                                                               
C                            ** Range 8.2-9.0 **                           
31    KI3=(3.742673E-5*X-7.157367E-4)*X+3.454768E-3                        
      RETURN                                                               
      END                                                                 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * G A U S C P *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     resolution, by gaussian elimination, of response fluxes          
C     for incomming currents and unitary source densities           
C     for a system of MMAX regions                         
C                                                                         
      SUBROUTINE GAUSCP(MMAX, 
     1                  SEC,  ST1,  VSI,  P,PA, GAM, X,Y)           
C                                                                         
      DIMENSION SEC(1),ST1(1)   ,VSI(1),P(MMAX,1),PA(MMAX,1),  
     1          GAM(1),X(MMAX,1),Y(1)        
C                                                                         
      DO 20 I=1,MMAX                                                      
      DO 10 J=1,MMAX                                                      
      X(I,J)=ST1(J)*P(J,I)                                                
   10 PA(J,I)=-SEC(I)*P(J,I)                                              
   20 PA(I,I)=PA(I,I)+VSI(I)                                              
C                                                                         
      DO 60 I=1,MMAX                                                      
      F=1.0/PA(I,I)                                                       
      Y(I)=F*GAM(I)                                                       
      DO 30 J=1,MMAX                                                      
   30 X(I,J)=F*X(I,J)                                                     
      IF(I.EQ.MMAX) GO TO 70                                              
      I1=I+1                                                              
      DO 40 J=I1,MMAX                                                     
   40 PA(I,J)=F*PA(I,J)                                                   
C                                                                         
      DO 60 J=I1,MMAX                                                     
      Y(J)=GAM(J)-Y(I)*PA(J,I)                                            
      DO 50 K=1,MMAX                                                      
   50 X(J,K)=X(J,K)-X(I,K)*PA(J,I)                                        
      DO 60 K=I1,MMAX                                                     
   60 PA(J,K)=PA(J,K)-PA(I,K)*PA(J,I)                                     
C                                                                         
   70 IMAX=MMAX-1                                                         
      IF(IMAX.EQ.0) GO TO 90                                              
      DO 80 I=1,IMAX                                                      
      J=MMAX-I                                                            
      J1=J+1                                                              
      DO 80 K=J1,MMAX                                                     
      Y(J)=Y(J)-Y(K)*PA(J,K)                                              
      DO 80 KK=1,MMAX                                                     
   80 X(J,KK)=X(J,KK)-X(K,KK)*PA(J,K)                                     
C                                                                         
   90 RETURN                                                              
      END                                                                 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                       
C     ***************                                                   
C     *             *                                                   
C     * G A U S D P *                                                   
C     *             *                                                   
C     ***************                                                   
C                                                                       
C     calcul of intermediate values for flux calculations        
C                                                                         
      SUBROUTINE GAUSDP(MMAX,
     1                  SEC,ST1,VSI,P,PA,Y,Q,GAM)                  
C
      DIMENSION SEC(1),ST1(1),VSI(1),P(MMAX,1),PA(MMAX,1),
     1          Y(1)  ,Q(1)  ,GAM(1)                         
C
      DO 5 I=1,MMAX                                                     
      GAM1=.0                                                           
      DO 5 J=1,MMAX                                                     
 5    GAM(I)=GAM1+Q(J)*ST1(J)*P(J,I)                                    
C
      DO 20 I=1,MMAX                                                    
      DO 10 J=1,MMAX                                                    
 10   PA(J,I)=-SEC(I)*P(J,I)                                            
 20   PA(I,I)=PA(I,I)+VSI(I)                                            
C
      DO 60 I=1,MMAX                                                    
      F=1.0/PA(I,I)                                                     
      Y(I)=F*GAM(I)                                                     
      IF(I.EQ.MMAX)GO TO 70                                             
      I1=I+1                                                            
      DO 40 J=I1,MMAX                                                   
 40   PA(I,J)=F*PA(I,J)                                                 
      DO 60 J=I1,MMAX                                                   
      Y(J)=GAM(J)-Y(I)*PA(J,I)                                          
      DO 60 K=I1,MMAX                                                   
 60   PA(J,K)=PA(J,K)-PA(I,K)*PA(J,I)                                   
C
 70   IMAX=MMAX-1                                                       
      IF(IMAX.EQ.0)GO TO 90                                             
C
      DO 80 I=1,IMAX                                                    
      J=MMAX-I                                                          
      J1=J+1                                                            
      DO 80 K=J1,MMAX                                                   
 80   Y(J)=Y(J)-Y(K)*PA(J,K)                                            
C
 90   RETURN                                                            
      END                                                               
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * C A L F L U *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     flux calculation for cylindrical geometry              
C                                                                         
      SUBROUTINE CALFLU(NREG,ALBEDO,AJEXT,     
     1                  V,XSR,YI,XIK,Q,VOLY,FLUQ,FLUJ,FI,REMO,XIK2,YI2)
C                                                                         
      DIMENSION  V(1)   ,XSR(1) ,YI(1),XIK(NREG,1),Q(1),VOLY(1),
     1           FLUQ(1),FLUJ(1),FI(1),REMO(1)    ,XIK2(NREG,1),YI2(1) 
C                                                                         
      COMMON/CPR001/NIN,NOT,NX1(2)                                        
C
      COMMON /CPR002/IXX1,NX202,NX204,XX2,SB,NX203                       
C                                                                         
      REAL JMINUS,JNET,JPLUS                    
C                                                                         
      QSB=0.25*SB                                                         
      AQSB=ALBEDO*QSB                                                     
      Y=1.0                                                               
C
      DO I=1,NREG                                                      
       VOLY(I)=V(I)*YI(I)                                                  
       Y=Y - VOLY(I)*XSR(I)                                                
      ENDDO
C
      ALBY=ALBEDO*Y                                                       
      IF(ALBY.EQ.1.0)GO TO 60                                             
      BFACT=1.0/(1.0 - ALBEDO*Y)                                          
      GO TO 70                                                            
C
 60   BFACT=1.0E+20                                                       
C
 70   DO 30 I=1,NREG                                                      
      YI2(I)=BFACT*YI(I)                                                  
      FACT=AQSB*YI2(I)                                                    
      DO 30 K= 1 , NREG                                                   
 30   XIK2(I,K)=XIK(I,K) + FACT*VOLY(K)                                   
C
      DO 50 I=1,NREG                                                      
      SUM=0.0                                                             
      DO 40 K=1 , NREG                                                    
 40   SUM=SUM + Q(K)*XIK2(I,K)                                            
      FLUJ(I)=AJEXT*YI2(I)                                                
 50   FI(I)=SUM+FLUJ(I)                                                   
C
      RETURN                                                              
      END                                                                 
C******************************************************************
C
C     ***************                                                     
C     *             *                                                     
C     * S A L I D A *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     write results            
C                                                                         
      SUBROUTINE SALIDA(NREG,ISMAX,NMAT,NISO,NCASOS,
     1                  ISMA  ,DUGG  ,DN    ,SIMBO ,MATR  ,NRZ   ,        
     2                  ID    ,NRES  ,V     ,TEMP  ,XS22  ,C     ,        
     3                  RIR   ,R     ,FR    ,XSC   ,RIC   ,RC    ,        
     4                  RREM  ,RIZ   ,XSRR  ,RZ    ,RIEXA)                
C
C                                                                         
      DIMENSION ISMA(1)     ,DUGG(1)     ,DN(NMAT,1)  ,SIMBO(1)    ,      
     1          MATR(1)     ,NRZ(1)      ,ID(NMAT,1)  ,NRES(1)     ,      
     2          V(1)        ,TEMP(1)     ,XS22(NISO,1),C(1)        ,      
     3          RIR(NREG,ISMAX,1)        ,R(1)        ,FR(1)       ,      
     4          XSC(1)      ,RIC(NISO,1) ,RC(1)       ,RREM(NREG,1),      
     5          RIZ(ISMAX,1),XSRR(1)     ,RZ(1)       ,                   
     6          RIEXA(NREG,ISMAX,1)      ,IARRAY(3)                       
C
C
      COMMON/A/ ID1, ID2 ,ID3 ,ID4 ,ID5 ,ID10,                            
     1          IS6 ,IS7 ,IS8 ,IS9                                        
C                                                                         
      COMMON/B/ NGG   ,NXX1  ,ISRES ,NRSUM ,NGI   ,NTABXA,                
     1          NXX2  ,NXX4  ,NZ    ,NXX5  ,NIRMAX,NX    ,                
     2          NX1   ,IGF   ,INTER ,ICASO ,IENTRA,NGFT  ,                
     3          IGG   ,IGI   ,IGFABS,NGF1  ,NGF2  ,NGFI  ,                
     4          NGFI2 ,INXS  ,IT10  ,IT62  ,IGIAN ,IM    ,                
     5          IG                                                        
C                                                                         
      COMMON/C/ EMAX  ,DUGF  ,ALBEDO,AJEXT ,ANUFIS,URLAM ,                
     1          DUGI  ,SA    ,SB    ,SD    ,RE2SM ,VTOT  ,                
     2          PG    ,U     ,U3    ,Q0C   ,E22   ,EM    ,                
     3          SA1MIN,PG1   ,XSB   ,PERCON,SCOP  ,DXST(3),EMAR           
C                                                                         
      COMMON/D/ IOPI(16)                                                  
C                                                                         
      COMMON/F/TIT                                                    
C                                                                         
      COMMON/G/I0I(10),IPCAL(3)                                           
C
C                                                                         
  2   FORMAT(1X,A80)                                                     
C                                                                       
  3   FORMAT(1X,3I4,' TOT ',1P3E12.5,48X,1PE12.5,/)            
C                                                                         
  4   FORMAT(1X,3I4,1X,A4,1P7E12.5)                                       
C                                                                         
  5   FORMAT(1X,3I4,' TOT ',1P8E12.5,/)                         
C                                                                         
  6   FORMAT(1X,I4,' TOT',I4,1X,A4,1P7E12.5)                              
C                                                                         
  7   FORMAT(1X,I4,' TOT',I4,' TOT ',1P8E12.5 ,/)                
C                                                                         
  8   FORMAT(1X,I4,' CELL    ',A4,1P7E12.5)                               
C                                                                         
  9   FORMAT(1X,I4,' CELL    TOT ',1P9E12.5,/)                   
C                                                                         
  10  FORMAT(1X,I2,I5,3X,A4,1P7E12.5)                                     
C                                                                         
  11  FORMAT(1X,I2,I5,3X,'TOT ',1P9E12.5,/)                      
C                                                                       
  13  FORMAT(1X,2I4,A4,1P6E12.5)                                          
C                                                                         
  14  FORMAT(1X,2I4,A4,1P2E12.5,12X,1PE12.5,12X,1PE12.5)      
C                                                                         
  15  FORMAT(1X,2I4,A4,1P4E12.5)                                          
C                                                                         
  16  FORMAT(1X,'TEMPERATURE :',F8.3,' K',/)                     
C                                                                         
  17  FORMAT(3E12.5)                                                      
C                                                                         
  18  FORMAT(1X,3I4,1X,A4,1P3E12.5,12X,1P3E12.5)                          
C                                                                         
  19  FORMAT(1X,3I4,' TOT ',1P3E12.5,12X,1P4E12.5,/)             
C                                                                         
  21  FORMAT(1X,3I4,' TOT ',1P4E12.5,36X,1PE12.5,/)              
C                                                                       
  22  FORMAT(1X,'  IG',9X,'XSB   RI/TAU-AB  NU*R/T-F',/)            
C                                                                       
  24  FORMAT(1X,I4,' TOT',I4,1X,A4,1P3E12.5,12X,1P3E12.5)                 
C                                                                         
  25  FORMAT(1X,I4,' TOT',I4,' TOT ',1P3E12.5,12X,1P4E12.5,/)    
C                                                                         
  26  FORMAT(1X,I4,' TOT',I4,' TOT ',1P4E12.5,36X,1PE12.5,/)     
C                                                                         
  27  FORMAT(1X,I4,' TOT',I4,' TOT ',1P3E12.5,48X,1PE12.5,/)     
C                                                                       
  29  FORMAT(I5,1P3E12.5)                                               
C                                                                         
  31  FORMAT(1X,I4,' CELL   ',1X,A4,1P3E12.5,12X,1P3E12.5)                
C                                                                         
  32  FORMAT(1X,I4,' CELL    TOT ',1P3E12.5,12X,1P5E12.5,/)      
C                                                                         
  33  FORMAT(1X,I4,' CELL    TOT ',1P4E12.5,36X,1P2E12.5,/)      
C                                                                         
  34  FORMAT(1X,I4,' CELL    TOT ',1P3E12.5,48X,1P2E12.5,/)      
C                                                                         
C                                                                         
      CHARACTER*80 TIT
C
      CHARACTER*8 HORA                                                  
C                                                                       
      CHARACTER*9 FECHA                                                 
C
      print *,"FINISH CALCULATIONS FOR BROAD GROUP ",IGG
C                                                                         
      IF(ICASO.EQ.1)THEN
C                                             
       IF(IGG.EQ.1)THEN
C                                               
        CALL TITULO(1)                                                      
C
C       general title                                                      
C                                                                         
        CALL TITULO(1)                                                      
        CALL TITULO(2)                                                      
C                                                                         
C       title of the problem                                                 
C                                                                         
        WRITE(IS6,2)TIT                                                     
        WRITE(*,2)TIT                                                     
        CALL TITULO(1)                                                      
C                                                                         
        IF(IOPI(1).EQ.0)THEN                                           
C                                                                         
C        output for homogeneous mixtures
C                                                                          
C        write temperature of the mixture                            
C                                                                         
         WRITE(IS6,16)TEMP(1)                                                
         IOPI31  =IOPI(3)+1                                                  
C
         IF(IOPI31.EQ.1)THEN
C                                                                         
C         Calcul XS (homogeneous mixture)                                    
C                                                                         
          CALL TITULO(4)                                                      
C
         ELSEIF(IOPI31.EQ.2)THEN 
C                                                                         
C         Calcul resonance integrals                                  
C                                                                         
          CALL TITULO(5)                                                      
          IOPI41  =IOPI(4)+1                                                  
          CALL TITULO(8)                                                      
          CALL TITULO(9)                                                      
C
         ELSE  
C                                                                         
C         Calcul of lambda                                                   
C                                                                         
          CALL TITULO(10)                                                     
          CALL TITULO(11)                                                     
C
         ENDIF
C
        ELSE
C                                                                         
C     pin cells                                                 
C                                                                         
         CALL TITULO(12)                                                     
C
        ENDIF
C
       ENDIF
C
      ENDIF
C                                                                            
C     output for pin cells                       
C                                                                         
      IF(IOPI(1).EQ.1)THEN                                           
C                                                                         
C      initial values                                                   
C                                                                         
       IA1=1                                                               
       IF1=2                                                               
       IS1=3                                                               
       IR1=4                                                               
       IAR1=5                                                              
       IFR1=6                                                              
       ISR1=7                                                              
       IZ=1                                                                
       IRZ=1                                                               
       NXX=NX+1                                                            
       NXXX1=2*NX+1                                                        
       NX11=NXX+1                                                          
       FZ=0.0                                                              
       VZ=0.0                                                              
       FC=0.0                                                              
C
       DO I=1,NXXX1                                                    
C
        DO J1=1,ISMAX                                                   
         RIZ(J1,I)=0.0                                                       
        ENDDO
C
        RZ(I)=0.0                                                           
        RC(I)=0.0                                                           
C
        DO J2=1,NISO                                                    
         RIC(J2,I)=0.0                                                       
        ENDDO                                                            
C
       ENDDO
C                                                                         
C      output for each region                                          
C                                                                       
       VVR=0.0                                                             
C
       DO I=1,NREG                                                     
C
        IM=MATR(I)                                                          
        NI=ISMA(IM)                                                         
C
        DO I1=1,NXXX1                                                   
         XSRR(I1)=0.0                                                        
        ENDDO                                                            
C                                                                         
C       output for each isotope                               
C                                                                         
        DO J=1,NI                                                       
C
         JJ=ID(IM,J)                                                         
C
         DO I2=1,NX                                                      
C                                                                         
C         macr.XS's of each isotope                         
C                                                                         
          R(I2)=RIR(I,J,I2)/FR(I)                                             
          RIZ(J,I2)=RIZ(J,I2)+RIR(I,J,I2)*V(I)                                
C
         ENDDO                                                            
C                                                                         
C        removal XS                                            
C                                                                         
         F=SB*C(JJ)/SA                                                       
         XSR1=R(NX)-RREM(I,J)*F/FR(I)                                        
         IF(XSR1.LT.0.0)XSR1=0.0                                             
         XSRR(NXX)=XSRR(NXX)+XSR1                                            
         RIZ(J,NXX)=RIZ(J,NXX)+XSR1*FR(I)*V(I)                               
C                                                                         
C        total XS's of the region                                   
C                                                                         
         DO I3=1,NX                                                      
          XSRR(I3)=XSRR(I3)+R(I3)                                             
         ENDDO
C
C        output for each isotope                     
C                                                                         
         IF(NRES(JJ).GT.0)THEN                                          
C                                                                         
C        reso isotopes 
c
          DO I5 =1,NX                                                     
           IF(R(I5 ).LT.1.0E-10)R(I5 )=0.0                                     
           IF(RIEXA(I,J,I5 ).LT.1.0E-10)RIEXA(I,J,I5 )=0.0   
          ENDDO
C
          IF(IOPI(3).EQ.1)THEN                                           
C
           R11=RIEXA(I,J,IA1)*DUGF                                             
           R12=RIEXA(I,J,IF1)*DUGF                                             
           R13=RIEXA(I,J,IS1)*DUGF                                             
C
           WRITE(IS6,4)IGG,IRZ,IZ,SIMBO(JJ),(R(ISS1),ISS1=1,NX),XSR1,
     1                                       R11,R12,R13                                             
C     
          ENDIF
C
         ENDIF
C
         IF(IOPI(3).EQ.0.OR.NRES(JJ).EQ.0)THEN
C
C         macr.XS's
C
          WRITE(IS6,4)IGG,IRZ,IZ,SIMBO(JJ),(R(ISS3),ISS3=1,NX),XSR1           
C
C         micr.XS's 
C
          DNN=DN(IM,J)
          WRITE(IS6,4)IGG,IRZ,IZ,SIMBO(JJ),(R(ISS3)/DNN,ISS3=1,NX),
     1                                      XSR1/DNN 
C
         ENDIF
C
         IF(NRES(JJ).GT.0)THEN                                          
C                                                                         
C         total reso integral for region and zone, for each isotope    
C                                                                         
          II2=0                                                               
C
          DO I6=NX11,NXXX1                                                
           II2=II2+1                                                           
           XSRR(I6)=XSRR(I6)+RIEXA(I,J,II2)*DUGF                               
           RIZ(J,I6)=RIZ(J,I6)+RIEXA(I,J,II2)*DUGF*V(I)                        
          ENDDO
C
         ENDIF
C
        ENDDO                                                            
C
        FZ=FZ+FR(I)*V(I)                                                    
        VZ=VZ+V(I)                                                          
C                                                                         
C       output for the region                    
C                                                                         
        DO I8 =1,NXXX1                                                  
         IF(XSRR(I8).LT.1.0E-10)XSRR(I8 )=0.0                               
        ENDDO
C
        FR10=FR(I)*DUGF                                                     
C
        IF(IOPI(3).EQ.1)THEN                                           
C  
         WRITE(IS6,5)IGG,IRZ,IZ,(XSRR(ISS5),ISS5=1,NXXX1),FR10
C      
        ELSEIF(IOPI(3).EQ.0)THEN
C
         WRITE(IS6,21)IGG,IRZ,IZ,(XSRR(ISS8),ISS8=1,NXX),FR10                
C
        ENDIF
C
        IF(IRZ.EQ.NRZ(IZ))THEN                                         
C                                                                         
C       zone totals                                         
C                                                                         
         DO I7=1,NXXX1                                                   
          DO J12=1,NI                                                     
           RZ(I7)=RZ(I7)+RIZ(J12,I7)               
          ENDDO                                                            
         ENDDO                                                            
C                                                                         
C        output for each zone                                            
C                                                                         
         DO J=1,NI                                                       
C
          JJ=ID(IM,J)                                                         
C                                                                         
C         output for each isotope                     
C                                                                         
          DO I9=1,NXXX1                                                  
           IF(RIZ(J,I9).LT.1.0E-10)RIZ(J,I9 )=0.0                             
          ENDDO                                                            
C
          RIZ101=RIZ(J,IA1)/FZ                                                
          RIZ102=RIZ(J,IF1)/FZ                                                
          RIZ103=RIZ(J,IS1)/FZ                                                
          RIZ104=RIZ(J,IR1)/FZ                                                
C
          IF(IOPI(3).EQ.1.AND.NRES(JJ).GT.0)THEN                                           
C 
           RIZ111=RIZ(J,IAR1)/VZ                                               
           RIZ112=RIZ(J,IFR1)/VZ                                               
           RIZ113=RIZ(J,ISR1)/VZ                                               
C
           WRITE(IS6,6)IGG,IZ,SIMBO(JJ),RIZ101,RIZ102,RIZ103,RIZ104,
     1                                  RIZ111,RIZ112,RIZ113                   
          ENDIF
C
          IF(IOPI(3).EQ.0.OR.NRES(JJ).EQ.0)THEN
C
           WRITE(IS6,6)IGG,IZ,SIMBO(JJ),RIZ101,RIZ102,RIZ103,RIZ104            
C
C          macr.XS's 
C    
           DNN=DN(IM,J)
           WRITE(IS6,6)IGG,IZ,SIMBO(JJ),RIZ101/DNN,RIZ102/DNN,
     1                                  RIZ103/DNN,RIZ104/DNN
C
          ENDIF
C
          DO I10=1,NXXX1                                                  
           RIC(JJ,I10)=RIC(JJ,I10)+RIZ(J,I10)                  
           RIZ(J,I10)=0.0                                     
          ENDDO
C
         ENDDO
C                                                                         
C        output of totals over the zone                                
C                                                                         
         DO I11=1,NXXX1                                                  
          IF(RZ(I11).LT.1.0E-10)RZ(I11)=0.0                                   
         ENDDO                                                            
C
         RZ101=RZ(IA1)/FZ                                                    
         RZ102=RZ(IF1)/FZ                                                    
         RZ103=RZ(IS1)/FZ                                                    
         RZ104=RZ(IR1)/FZ                                                    
         FZ10=FZ*DUGF/VZ                                                     
C
         IF(IOPI(3).EQ.1)THEN                                           
C
          RZ111=RZ(IAR1)/VZ                                                   
          RZ112=RZ(IFR1)/VZ                                                   
          RZ113=RZ(ISR1)/VZ                                                   
C
          WRITE(IS6,7)IGG,IZ,RZ101,RZ102,RZ103,RZ104,                         
     1                       RZ111,RZ112,RZ113,FZ10                           
         ELSEIF(IOPI(3).EQ.0)THEN                                                           
C
          WRITE(IS6,26)IGG,IZ,RZ101,RZ102,RZ103,RZ104,FZ10                    
C
         ENDIF
C
         FC=FC+FZ                                                            
C
         DO I12=1,NXXX1                                                  
          RC(I12)=RC(I12)+RZ(I12)                                             
          RZ(I12)=0.0                                                         
         ENDDO                                                            
C
         FZ=0.0                                                              
         VZ=0.0                                                              
         IRZ=1                                                               
         IZ=IZ+1                                                             
C
        ELSE
         IRZ=IRZ+1                                                           
        ENDIF
C
       ENDDO                                                            
C                                                                         
C      output for the cell                                           
C                                                                       
C      output for each isotope                               
C                                                                         
       DO J=1,NISO                                                     
C
        DO I1=1,NXXX1                                                   
         IF(RIC(J,I1).LT.1.0E-10)RIC(J,I1)=0.0                               
        ENDDO                                                            
C
        RIC101=RIC(J,IA1)/FC                                                
        RIC102=RIC(J,IF1)/FC                                                
        RIC103=RIC(J,IS1)/FC                                                
        RIC104=RIC(J,IR1)/FC                                                
C
        IF(IOPI(3).EQ.1.AND.NRES(JJ).GT.0)THEN                                           
C
         RIC111=RIC(J,IAR1)/VTOT                                             
         RIC112=RIC(J,IFR1)/VTOT                                             
         RIC113=RIC(J,ISR1)/VTOT                                             
C
         WRITE(IS6,8)IGG,SIMBO(J),RIC101,RIC102,RIC103,RIC104,               
     1                           RIC111,RIC112,RIC113                       
        ENDIF
C
        IF(IOPI(3).EQ.0.OR.NRES(JJ).EQ.0)THEN
C
         WRITE(IS6,8)IGG,SIMBO(J),RIC101,RIC102,RIC103,RIC104                
C
        ENDIF
C
       ENDDO                                                            
C                                                                         
C      cell totals                                        
C                                                                         
       DO I2=1,NXXX1                                                   
        IF(RC(I2).LT.1.0E-10)RC(I2)=0.0                                     
       ENDDO                                                            
C
       FC100=FC*DUGF/VTOT                                                  
       RC101=RC(IA1)/FC                                                    
       RC102=RC(IF1)/FC                                                    
       RC103=RC(IS1)/FC                                                    
       RC104=RC(IR1)/FC                                                    
C
       IF(IOPI(3).EQ.1)THEN                                           
C
        RC111=RC(IAR1)/VTOT                                                 
        RC112=RC(IFR1)/VTOT                                                 
        RC113=RC(ISR1)/VTOT                                                 
C
        WRITE(IS6,9)IGG,RC101,RC102,RC103,RC104,                            
     1                  RC111,RC112,RC113,FC100                             
       ENDIF                                                 
C       
       IF(IOPI(3).EQ.0)THEN
C
        WRITE(IS6,33)IGG,RC101,RC102,RC103,RC104,FC100                      
C
       ENDIF
C
      ELSE
C                                                                         
C      homogeneous case                                                       
C                                                                         
       IF(IOPI31.EQ.1)THEN
C                                                                         
C      output of XS's and resonance integrals                       
C                                                                         
        CALL TITULO(13)                                                     
        XSR1=0.0                                                            
        NXX=NX+1                                                            
        NXXX1=2*NX+1                                                        
C
        DO I1=1,NXXX1                                                   
         XSRR(I1)=0.0                                                        
        ENDDO
C
        II1=1                                                               
C
        DO J=1,NISO                                                     
C
         DO I2=1,NX                                                      
          R(I2)=RIR(II1,J,I2)/FR(II1)                         
         ENDDO
C
         F=SB*C(J)/SA                                                        
         XSR1=R(NX)-RREM(II1,J)*F/FR(II1)                                    
         XSRR(NXX)=XSRR(NXX)+XSR1                                            
C
         DO I3=1,NX                                                      
          XSRR(I3)=XSRR(I3)+R(I3)                                
         ENDDO
C
         IF(NRES(J).GT.0)THEN                                           
C
          DO I4=1,NX                                                      
           RIEXA(II1,J,I4)=RIR(II1,J,I4)*PFAC             
          ENDDO
C
          DO I15=1,NX                                                     
           IF(R(I15).LT.1.0E-10)R(I15)=0.0                     
           IF(RIEXA(II1,J,I15).LT.1.0E-10)RIEXA(II1,J,I15)=0.0        
          ENDDO
C
          WRITE(IS6,10)IGG,ICASO,SIMBO(J),(R(I),I=1,NX),XSR1,                 
     1                                    (RIEXA(II1,J,I5)*DUGF,I5=1,NX)
          NX11=NXX+1                                                          
          II6=0                                                               
C
          DO I6=NX11,NXXX1                                                
           II6=II6+1                                           
           XSRR(I6)=XSRR(I6)+RIEXA(II1,J,II6)*DUGF                         
          ENDDO
C
         ENDIF                                                           
C         
         IF(NRES(J).EQ.0)THEN
C
          WRITE(IS6,10)IGG,ICASO,SIMBO(J),(R(I7),I7=1,NX),XSR1  
C
         ENDIF
C
        ENDDO
C
        DO I16=1,NX                                                     
         IF(XSRR(I16).LT.1.0E-10)XSRR(I16)=0.0                               
        ENDDO                                                            
C
        WRITE(IS6,11)IGG,ICASO,(XSRR(I8),I8=1,NXXX1),FR(II1)*DUGF,PGG
C
       ELSEIF(IOPI31.EQ.2)THEN
C                                                                         
C      calcul of WIMSD type resonance integrals vs. XSb
C                                                                         
C       read reference reso integrals for comparisons                 
C                                                                         
        IF(IOPI(11).EQ.1)THEN                                          
C
         IF(IGG.EQ.1.AND.ICASO.EQ.1)THEN                                                  
          OPEN(UNIT=ID4,FILE='RI.DAT',FORM='FORMATTED',STATUS='OLD') 
         ENDIF                                                             
C
         READ(ID4,29)IGGDUM,XSBDUM,(RZ(I),I=1,2) 
C
        ENDIF
C
        II1=1                                                               
C
        DO I=1,NX                                                       
         R(I)=RIR(II1,II1,I)/(FR(II1)*DN(II1,II1))                           
        ENDDO                                                            
C
        DO I=1,NX                                                       
         ANU=1.0                                                             
         IF(I.EQ.2)ANU=ANUFIS                                                
         RIEXA(II1,II1,I)=R(I)*XSB*ANU/(R(II1)+XSB)                          
         IF(IOPI(11).EQ.1.AND.I.LE.2)THEN
          XSRR(I)=(RIEXA(II1,II1,I)/RZ(I)-1.0)*100.0
         ENDIF
        ENDDO
C                                                                         
C       write (on RI.OUT)  RI/TAU vs. XSb                                
C                                                                         
        IF(ICASO.EQ.1.AND.IGG.EQ.1)THEN                                   
         OPEN(UNIT=60,FILE='RI.OUT',FORM='FORMATTED',STATUS='NEW') 
        END IF                                                              
C
        III1=II1+1                                                          
        WRITE(60,29)IGG,XSB,RIEXA(II1,II1,II1),RIEXA(II1,II1,III1) 
C
        IF(IOPI(11).EQ.1)THEN                                          
C
        WRITE(IS6,13)IGG,ICASO,SIMBO(II1),XSB,
     1        (RIEXA(II1,II1,I),XSRR(I),I=1,2),RIEXA(II1,II1,3)
C
        ENDIF                                               
C
        IF(IOPI(11).EQ.0)THEN
C
         WRITE(IS6,14)IGG,ICASO,SIMBO(II1),XSB,
     1                (RIEXA(II1,II1,I),I=1,NX)
C
        ENDIF
C
       ELSEIF(IOPI31.EQ.3)THEN
C                                                                         
C       data for lambda calculations                                
C                                                                         
        II1=1                                                               
        II2=2                                                               
        II3=3                                                               
        AX=RIR(II1,II1,II1)/FR(II1)                                         
C
        IF(ICASO.EQ.1.AND.IGG.EQ.1)THEN                                   
         OPEN(UNIT=70,FILE='ABSXS',FORM='FORMATTED',STATUS='NEW') 
         WRITE(70,'(A80)')TIT   
         WRITE(70,'(2I5)')NGG,NCASOS
         WRITE(70,'(1P6E12.5)')(DUGG(KK),KK=1,NGG)
         WRITE(70,'(1P4E12.5)')XS22(II1,II3),XS22(II2,II3),
     1                         XS22(II3,II3),URLAM          
        END IF                                                              
C
        IF(IGG.EQ.1)THEN
         WRITE(70,'(1P2E12.5)')DN(II1,II2),DN(II1,II3)
        ENDIF
C         
        WRITE(70,'(1PE12.5)')AX
        WRITE(IS6,'(I5,1P2E12.5)')IGG,DN(II1,II2),AX
       ENDIF
C
      ENDIF
C                                                                         
C     reset FR() y RIR(,,)                                        
C                                                                         
      DO I=1,NREG                                                     
       J=1                                                                 
       FR(I)=0.0                                                           
       IF(IOPI(1).EQ.1)J=MATR(I)                                                           
       K=ISMA(J)                                                           
       DO I1=1,K                                                       
        DO I2=1,NX                                                      
         RIR(I,I1,I2)=0.0                                                    
         RIEXA(I,I1,I2)=0.0                                                  
        ENDDO
        RREM(I,I1)=0.0                                                      
       ENDDO
      ENDDO
C                                                                         
      RETURN                                                              
      END                                                                
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                         
C     ***************                                                     
C     *             *                                                     
C     * T I T U L O *                                                     
C     *             *                                                     
C     ***************                                                     
C                                                                         
C     print output titles       
C                                                                         
      SUBROUTINE TITULO(N)                                                
C                                                                         
      COMMON/A/ ID1,ID2,ID3,ID4,ID5,ID10,                                 
     1         IS6,IS7,IS8,IS9                                            
C                                                                         
  1   FORMAT('--------------------------------------------------------')                                                    
C                                                                         
  2   FORMAT(6X,'*******************',/,                                  
     1       6X,'*                 *',/,                                  
     2       6X,'*   R M E T 2 1   *',/,                                  
     3       6X,'*                 *',/,                                  
     4       6X,'*******************',//,                                  
     5       6X,'AUTHOR: FRANCISCO LESZCZYNSKI',/,                         
     6       6X,'CENTRO ATOMICO BARILOCHE-CNEA-ARGENTINA',/,
     7       6X,'FIRST VERSION: FEBRUARY 1985',/,                  
     8       6X,'LAST VERSION:  MARCH 1999',/)                      
C                                                                         
  3   FORMAT(1X,'----------------',/)                            
C                                                                         
  4   FORMAT(1X,'Macroscopic XS Calculation',/)                                             
c
  5   FORMAT(1X,'Resonance Integrals Calculation',/)                                                  
C                                                                         
  6   FORMAT(1X,'---',/)                     
C                                                                         
  7   FORMAT(1X,'----------',/)    
C                                                                         
  8   FORMAT(1X,'WIMS Method',/)                                 
C                                                                         
  9   FORMAT(1X,'GRO CASE ISO',5X,'XSB',9X,'IA',9X,'DIA',10X,'IF',10X,    
     1'DIF',10X,'IS',10X,'DIS',9X,'PG',/)                        
C                                                                         
  10  FORMAT(1X,'LAMBDA FACTOR CALCULATION',/)                                                  
C                                                                         
  11  FORMAT('GROUP   DNH      XSA',/)                                                  
C                                                                         
  12  FORMAT(1X,'Cilinderized Cell',//,                        
     12X,'GRO REG ZON  ISO',5X,'XSA',9X,'XSF',9X,'XSS',9X,'XSR',9X,       
     2'IA',10X,'IF',10X,'IS',10X,'FLU',9X,'PG',/)                
C                                                                         
  13  FORMAT(1X,'GRO CASE   IS      XSABS',7X,'XSFIS',7X,'XSDIS',7X,      
     2'XSREM',7X,'IA',10X,'IF',10X,'IS',10X,'FLUX',6X,'PROB.ESC.ABS.',/)       
C                                                                         
C 
      GO TO (100,200,300,400,500,600,700,800,900,1000,1100,1200,1300),N   
  100 WRITE(IS6,1)                                                        
      GO TO 2000                                                          
  200 WRITE(IS6,2)                                                        
      GO TO 2000                                                          
  300 WRITE(IS6,3)                                                        
      GO TO 2000                                                          
  400 WRITE(IS6,4)                                                        
      GO TO 2000                                                          
  500 WRITE(IS6,5)                                                        
      GO TO 2000                                                          
  600 WRITE(IS6,6)                                                        
      GO TO 2000                                                          
  700 WRITE(IS6,7)                                                        
      GO TO 2000                                                          
  800 WRITE(IS6,8)                                                        
      GO TO 2000                                                          
  900 WRITE(IS6,9)                                                        
      GO TO 2000                                                          
 1000 WRITE(IS6,10)                                                       
      GO TO 2000                                                          
 1100 WRITE(IS6,11)                                                       
      GO TO 2000                                                          
 1200 WRITE(IS6,12)                                                       
      GO TO 2000                                                          
 1300 WRITE(IS6,13)                                                       
C                                                                         
 2000 RETURN                                                              
      END                                                                 
      SUBROUTINE TIMEDATE    
          character * 11, time_result, date_result
c          call system("cls") 
          call time (time_result)
          write(4,'("  The current time is: ",a11)')time_result
          print *, "  The current time is: ",time_result
          call date (date_result)
          write(4,'("  The current date is: ",a11)')date_result
          print *, "  The current date is: ",date_result
      RETURN
      END
